<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Announcements extends MY_Controller {

	public function __construct(){
		parent::__construct();

		if (!$this->input->is_ajax_request()) {
			$this->load->error_404($this->data);
		}

		$this->load->library('form_validation_rules/admin_rules');

		$this->load->model('announcement_model');
	}



	/********************************Add Announcement Modal Start ***********************************/
	public function add_announcement_modal(){

		$this->return['success'] = TRUE;
	
		$this->return['modal'] = $this->load->view('admin/xhr/announcements/add_announcement_modal', $this->data, TRUE);

		$this->return['modal_id'] = "add-announcement-modal";

		echo json_encode($this->return);
	}
	/********************************Add Announcement Modal End *************************************/




	/********************************Add Announcement Start ***********************************/
	public function add_announcement(){

		$this->form_validation->set_rules($this->admin_rules->add_announcement());

		if ($this->form_validation->run()) {


			$add_announcement_data = 
			[
				'announcement_title'         => $this->input->post('announcement_title'),
				'announcement_desc'          => $this->input->post('announcement_desc'),
				'announcement_members'       => $this->input->post('announcement_members'),
				'announcement_announce_date' => db_date_format($this->input->post('announcement_announce_date')),
				'announcement_created_by'    => $this->session->userdata('_user_id')
            ];
			

			if ($this->announcement_model->add_announcement($add_announcement_data)) {

            	$this->return['success'] = "Announcement created successfully...";

				$this->return['close'] = TRUE;
            }
            else{
            	$this->return['error'] = array();

				$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
            } 


            foreach ($_POST as $post_key => $post_value) {
				$this->return['no_error'][$post_key] = NULL;
			} 
		}
		else{

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Please complete fields correctly...";

			foreach ($_POST as $each_post_key => $each_post_val) {
				$this->return['error'][$each_post_key] = form_error($each_post_key);
			}
		}

		echo json_encode($this->return);		
	}
	/********************************Add Announcement End ***********************************/



	/******************************* Announcement List Start ***********************************/
	public function announcement_list(){
		
		$request_data = $_REQUEST;

		$limit  = isset($request_data['length']) ? $request_data['length'] : 10;
		$offset = isset($request_data['start'])  ? $request_data['start']  : 0;


		// getting total number records without any search
		$data = $this->announcement_model->announcement_list(
						                                     [
							                                   'limit'    => $limit, 
							                                   'offset'   => $offset
					                                         ]
					                                        );

		$total_row_count = $this->announcement_model->announcement_list([ 'count' => 1]);	
		
		$total_filtered_count = $total_row_count;


		if (isset($request_data['search']['value']) && !empty($request_data['search']['value'])) {

			$data = $this->announcement_model->announcement_list(
							                                     [
										             	           'like'     => $request_data['search']['value'],
										             	           'limit'    => $limit,
										             	           'offset'   => $offset
											             	     ]
											             	    );


			$total_filtered_count = count($this->announcement_model->announcement_list(
					                                         	  [
	                                                                'like'     => $request_data['search']['value']
	                                                              ]));	
			
		}



		$final_data = [];


		if ($data) {
			foreach ($data as $i=> $each_data) {

				$nested_data = [];

				$nested_data[] = ($offset)+($i+1); 

				$nested_data[] = $each_data->announcement_title;

				$nested_data[] = "<a href=\"team-members/member-details/".$each_data->_user_id."\">
					                     <img src=\"".user_img($each_data->user_image, $each_data->user_gender)."\" 
					                          style=\"height:30px; width:30px;\" class=\"img-circle\">".
					                      $each_data->user_first_name." ".$each_data->user_last_name.
					             "</a>";

                $nested_data[] = formatDate($each_data->announcement_create_time);					             

                $nested_data[] = format_date($each_data->announcement_announce_date);	

                $nested_data[] = ucwords(str_replace('_', ' ', $each_data->announcement_members));

                if ($each_data->announcement_is_published) {

                	$nested_data[] = "<span class=\"label label-success\">Published</span>";

                	$btn = "<li>
          				     <a href='javascript:void(0);' class='fa fa-eye' style='color:#000;'
          				        onclick=\"open_modal('announcements/view-announcement', 
          				        '_announcement_id=".$each_data->_announcement_id."');\"> View
						     </a>
						    </li>";
                }
                else{
                	$nested_data[] = "<span class=\"label label-danger\">Not Published</span>";

                	$btn = "<li>
          				     <a href='javascript:void(0);' class='fa fa-pencil' style='color:#007bff;'
          				        onclick=\"open_modal('announcements/edit-announcement', 
          				        '_announcement_id=".$each_data->_announcement_id."');\"> Edit
						     </a>
						    </li>";
                }

                $nested_data[] = "<ul class=\"nav navbar-nav navbar-right\">
                                    <li class=\"dropdown\">
                    				<a href=\"javascript:void(0);\" class=\"dropdown-toggle\" 
                    				   data-toggle=\"dropdown\">
                    				   <i class=\"fa fa-cog\" ></i><b class=\"caret\"></b>
                    				</a>
                    				<ul class=\"dropdown-menu\">
                      				  ".$btn."
									  
									  <li>
                      				     <a href='javascript:void(0);' class='fa fa-trash' style='color:#dc3545;'
                      				        onclick=\"open_modal('announcements/delete-announcement', 
                      				        '_announcement_id=".$each_data->_announcement_id."');\"> Delete
									     </a>
									  </li>
                    				</ul>
                  					</li>
                  				</ul>"; 


                $final_data[] =  $nested_data;  
			}
		}


		$json_data = array(
							"draw"            => intval(isset($request_data['draw']) ? $request_data['draw'] : 1),   
							"recordsTotal"    => intval( $total_row_count ),  
							"recordsFiltered" => intval( $total_filtered_count ), 
							"data"            => $final_data
						);

		echo json_encode($json_data);  // send data as json format	  		
	}
	/******************************* Announcement List End ***********************************/



	/********************************Edit Announcement Modal Start ***********************************/
	public function edit_announcement_modal(){

		$_announcement_id = $this->input->post('_announcement_id');

		$announcement_data = $this->announcement_model->announcement_list(['_announcement_id' => $_announcement_id]);

		if (!$announcement_data) {
			
			$this->return['error'] = "Invalid data given";

		}
		elseif ($announcement_data->announcement_is_published) {

			$this->return['error'] = "You can't edit after announcement is published";
		}
		else{
			$this->return['success'] = TRUE;

			$this->data['announcement_data'] = $announcement_data;
	
			$this->return['modal'] = $this->load->view('admin/xhr/announcements/edit_announcement_modal', $this->data, TRUE);

			$this->return['modal_id'] = "edit-announcement-modal";
		}

		echo json_encode($this->return);
	}
	/********************************Edit Announcement Modal End *************************************/



	/********************************Edit Announcement Start **************************************/
	public function edit_announcement(){

		$_announcement_id = $this->input->post('_announcement_id');

		$announcement_data = $this->announcement_model->announcement_list(['_announcement_id' => $_announcement_id]);

		if (!$announcement_data) {
			
			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Invalid data given";

		}
		elseif ($announcement_data->announcement_is_published) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "You can't edit after announcement is published";
		}
		else{
			$this->form_validation->set_rules($this->admin_rules->add_announcement());

			if ($this->form_validation->run()) {

				$upd_announcement_data = 
				[
					'announcement_title'         => $this->input->post('announcement_title'),
					'announcement_desc'          => $this->input->post('announcement_desc'),
					'announcement_members'       => $this->input->post('announcement_members'),
					'announcement_announce_date' => db_date_format($this->input->post('announcement_announce_date'))
	            ];
			

				if ($this->announcement_model->update_announcement($_announcement_id, $upd_announcement_data)) {

	            	$this->return['success'] = "Announcement updated successfully...";

					$this->return['close'] = TRUE;
	            }
	            else{
	            	$this->return['error'] = array();

					$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
	            } 


	            foreach ($_POST as $post_key => $post_value) {
					$this->return['no_error'][$post_key] = NULL;
				}
			}
			else{

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Please complete fields correctly...";

				foreach ($_POST as $each_post_key => $each_post_val) {
					$this->return['error'][$each_post_key] = form_error($each_post_key);
				}
			}	
		}

		echo json_encode($this->return);
	}
	/********************************Edit Announcement End ****************************************/



	/********************************View Announcement Modal Start **************************************/
	public function view_announcement_modal(){

		$_announcement_id = $this->input->post('_announcement_id');

		$announcement_data = $this->announcement_model->announcement_list(['_announcement_id' => $_announcement_id]);

		if (!$announcement_data) {
			
			$this->return['error'] = "This announcement is no longer available";

		}
		elseif ($announcement_data->announcement_is_published==0) {

			$this->return['error'] = "This announcement is not published yet";
		}
		else{
			$this->return['success'] = TRUE;

			$this->data['announcement_data'] = $announcement_data;
	
			$this->return['modal'] = $this->load->view('admin/xhr/announcements/view_announcement_modal', $this->data, TRUE);

			$this->return['modal_id'] = "view-announcement-modal";
		}

		echo json_encode($this->return);
	}
	/********************************View Announcement Modal End ****************************************/




	/********************************Delete Announcement Modal Start ***********************************/
	public function delete_announcement_modal(){

    	$_announcement_id = $this->input->post('_announcement_id');

		$announcement_data = $this->announcement_model->announcement_list(['_announcement_id' => $_announcement_id]);

		if (!$announcement_data) {
			
			$this->return['error'] = "Invalid data given";

		}
		else{
			$this->return['success'] = TRUE;

			$this->return['modal_id'] = "delete-announcement-modal";

			$data['modal_id'] = "delete-announcement-modal";

			$data['modal_title'] = "Delete Announcement";

			$data['modal_body'] = "Are you sure to delete this announcement ?";

			$data['modal_link'] = "'announcements/delete-announcement'";

			$data['modal_data'] = "'_announcement_id=$_announcement_id'";

			$this->return['modal'] = $this->load->view('admin/xhr/confirm_delete_modal', $data, TRUE);
		}

		echo json_encode($this->return);
	}
	/********************************Delete Announcement Modal End ***********************************/




	/********************************Delete Announcement Start ***********************************/
	public function delete_announcement(){

		$_announcement_id = $this->input->post('_announcement_id');

		$announcement_data = $this->announcement_model->announcement_list(['_announcement_id' => $_announcement_id]);

		if (!$announcement_data) {
			
			$this->return['error'] = "Invalid data given";

		}
		else{

			$upd_announcement_data = [
				                       'announcement_is_delete'   => 1,
				                       'announcement_delete_time' => date('Y-m-d H:i:s')
			                         ];


			if ($this->announcement_model->update_announcement($_announcement_id, $upd_announcement_data)) {

				$this->return['success'] = "Announcement deleted successfully...";

				$this->return['close'] = TRUE;

				$this->return['modal_id'] = "delete-announcement-modal";
			}
			else{
				$this->return['error'] = "Some Problems Occured...Try Again Later";
			}
		}

		echo json_encode($this->return);
	}
	/********************************Delete Announcement End ***********************************/



	



}	