<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Attendence extends MY_Controller {

	public function __construct(){
		parent::__construct();

		if (!$this->input->is_ajax_request()) {
			$this->load->error_404($this->data);
		}

		$this->load->library('form_validation_rules/admin_rules');

		$this->load->model('attendence_model');
	}



	/********************************Add Attendence Modal Start ***********************************/
	public function add_attendence_modal(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$this->return['success'] = TRUE;

			$this->load->model('user_model');

			$this->data['users'] = $this->user_model->user_list(['user_role_id' => 2]);
	
			$this->return['modal'] = $this->load->view('admin/xhr/attendence/add_attendence_modal', $this->data, TRUE);

			$this->return['modal_id'] = "add-attendence-modal";
		}

		echo json_encode($this->return);
	}
	/********************************Add Attendence Modal End **************************************/



	/********************************Add Attendence Start ***********************************/
	public function add_attendence(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$this->form_validation->set_rules($this->admin_rules->add_attendence());

			if ($this->form_validation->run()) {

				$attendence_date     = db_date_format($this->input->post('attendence_date'));


				$check_attendence = $this->db->select("COUNT(_attendence_id) AS count")
				                             ->from('attendence')
				                             ->where('attendence_fin_year_id', $this->session->userdata('_fin_year_id'))
				                             ->where('attendence_user_id', $this->input->post('attendence_user_id'))
				                             ->where('attendence_date', $attendence_date)
				                             ->get()
				                             ->row()
				                             ->count;

                if ($check_attendence) {
                	$this->return['error'] = array();

					$this->return['common_error_msg'] = "Attendence already taken for this member on this date";
                }
                else{
                	$attendence_in_time  = $attendence_date." ".$this->input->post('attendence_in_time').":00";
					$attendence_out_time = $attendence_date." ".$this->input->post('attendence_out_time').":00";

					$seconds_diff = strtotime($attendence_out_time)-strtotime($attendence_in_time);

					if ($seconds_diff<=0) {
						$this->return['error'] = array();

					   $this->return['common_error_msg'] = "Out time should be after In time";
					}
					else{
						$attendence_login_hours = gmdate("H:i:s", $seconds_diff);

						$add_attendence_data = [
												  'attendence_fin_year_id' => $this->session->userdata('_fin_year_id'),
												  'attendence_user_id'     => $this->input->post('attendence_user_id'),
												  'attendence_date'        => $attendence_date,
												  'attendence_in_time'     => $attendence_in_time,
												  'attendence_out_time'    => $attendence_out_time,
												  'attendence_login_hours' => $attendence_login_hours 
						                       ];

	                    if ($this->attendence_model->add_attendence($add_attendence_data)) {

			            	$this->return['success'] = "Attendence added successfully...";

							$this->return['close'] = TRUE;
			            }
			            else{
			            	$this->return['error'] = array();

							$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
			            }


					}

					foreach ($_POST as $post_key => $post_value) {
						$this->return['no_error'][$post_key] = NULL;
					}
                }

			}
			else{

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Please complete fields correctly...";

				foreach ($_POST as $each_post_key => $each_post_val) {
					$this->return['error'][$each_post_key] = form_error($each_post_key);
				}
			}	
		}

		echo json_encode($this->return);
	}
	/********************************Add Attendence End ***********************************/





	/******************************* Attendence List Start ***********************************/
	public function attendence_list(){

		$ctrl = $this->input->get('ctrl');

		$_user_id = $this->input->get('_user_id');

		if (!$_user_id && !in_array($this->session->userdata('user_role_id'), [1,3])) {
			$_user_id = $this->session->userdata('_user_id');
		}

		$request_data = $_REQUEST;

		$limit  = isset($request_data['length']) ? $request_data['length'] : 10;
		$offset = isset($request_data['start'])  ? $request_data['start']  : 0;


		// getting total number records without any search
		$data = $this->attendence_model->attendence_list($this->session->userdata('_fin_year_id'),
						                                    [
							                                   'limit'    => $limit, 
							                                   'offset'   => $offset,
							                                   '_user_id' => $_user_id
					                                        ]
					                                     );

		$total_row_count = $this->attendence_model->attendence_list($this->session->userdata('_fin_year_id'),
				                                                    [  'count' =>  1, '_user_id' => $_user_id]);	
		
		$total_filtered_count = $total_row_count;


		if (isset($request_data['search']['value']) && !empty($request_data['search']['value'])) {

			$data = $this->attendence_model->attendence_list($this->session->userdata('_fin_year_id'),
						                                     [
									             	           'like'     => $request_data['search']['value'],
									             	           'limit'    => $limit,
									             	           'offset'   => $offset,
									             	           '_user_id' => $_user_id
										             	     ]);

			$total_filtered_count = count($this->attendence_model
				                               ->attendence_list($this->session->userdata('_fin_year_id'),
				                                         	  [
                                                                'like'     => $request_data['search']['value'],
                                                                'order_by' => $order_by,
                                                                '_user_id' => $_user_id
                                                              ]));	
			
		}



		$final_data = [];


		if ($data) {
			foreach ($data as $i=> $each_data) {

				$nested_data = [];

				$nested_data[] = ($offset)+($i+1); 


				if ($ctrl=="attendence" && in_array($this->session->userdata('user_role_id'), [1,3])) {
					$nested_data[] = "<a href=\"../team-members/member-details/".$each_data->_user_id."\">
					                     <img src=\"".user_img($each_data->user_image, $each_data->user_gender)."\" 
					                          style=\"height:30px; width:30px;\" class=\"img-circle\"> ".
					                      $each_data->user_first_name." ".$each_data->user_last_name.
					                 "</a>";
				}

				$nested_data[] = format_date($each_data->attendence_date);

				$nested_data[] = date('H:i', strtotime($each_data->attendence_in_time));

				$nested_data[] = date('H:i', strtotime($each_data->attendence_out_time));

				$nested_data[] = $each_data->attendence_login_hours;


				if ($ctrl=="attendence" && in_array($this->session->userdata('user_role_id'), [1,3])) {

					$nested_data[] = "<ul class=\"nav navbar-nav navbar-right\">
	                                    <li class=\"dropdown\">
	                    				<a href=\"javascript:void(0);\" class=\"dropdown-toggle\" 
	                    				   data-toggle=\"dropdown\">
	                    				   <i class=\"fa fa-cog\" ></i><b class=\"caret\"></b>
	                    				</a>
	                    				<ul class=\"dropdown-menu\">
	                      				  <li>
	                      				     <a href='javascript:void(0);' class='fa fa-pencil' style='color:#007bff;'
	                      				        onclick=\"open_modal('attendence/edit-attendence', 
	                      				        '_attendence_id=".$each_data->_attendence_id."');\"> Edit
										     </a>
										  </li>
										  <li>
	                      				     <a href='javascript:void(0);' class='fa fa-trash' style='color:#dc3545;'
	                      				        onclick=\"open_modal('attendence/delete-attendence', 
	                      				        '_attendence_id=".$each_data->_attendence_id."');\"> Delete
										     </a>
										  </li>
	                    				</ul>
	                  					</li>
	                  				</ul>";
                	
                }


                $final_data[] =  $nested_data;
			}
		}	


		$json_data = array(
							"draw"            => intval(isset($request_data['draw']) ? $request_data['draw'] : 1),   
							"recordsTotal"    => intval( $total_row_count ),  
							"recordsFiltered" => intval( $total_filtered_count ), 
							"data"            => $final_data
						);

		echo json_encode($json_data);  // send data as json format		
	}
	/******************************* Attendence List End *************************************/




	/********************************Edit Attendence Modal Start ***********************************/
	public function edit_attendence_modal(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$_attendence_id = $this->input->post('_attendence_id');

		    $attendence_data = $this->attendence_model->attendence_list($this->session->userdata('_fin_year_id'),['_attendence_id' => $_attendence_id]);

		    if (!$attendence_data) {

				$this->return['error'] = "Invalid data given";
			}
			else{
				$this->return['success'] = TRUE;

				$this->load->model('user_model');

			    $this->data['users'] = $this->user_model->user_list(['user_role_id' => 2]);

				$this->data['attendence_data'] = $attendence_data;
	
				$this->return['modal'] = $this->load->view('admin/xhr/attendence/edit_attendence_modal', $this->data, TRUE);

				$this->return['modal_id'] = "edit-attendence-modal";	
			}
		}

		echo json_encode($this->return);
	}
	/********************************Edit Attendence Modal End ***********************************/




	/********************************Edit Attendence Start ***********************************/
	public function edit_attendence(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "You are not authorized to access here !";
		}
		else{
			$_attendence_id = $this->input->post('_attendence_id');

		    $attendence_data = $this->attendence_model->attendence_list($this->session->userdata('_fin_year_id'),['_attendence_id' => $_attendence_id]);

		    if (!$attendence_data) {

		    	$this->return['error'] = array();

				$this->return['common_error_msg'] = "Invalid data given";
			}
			else{
				$this->form_validation->set_rules($this->admin_rules->add_attendence());

				if ($this->form_validation->run()) {

					$attendence_in_time  = $attendence_data->attendence_date." ".$this->input->post('attendence_in_time').":00";
					$attendence_out_time = $attendence_data->attendence_date." ".$this->input->post('attendence_out_time').":00";

					$seconds_diff = strtotime($attendence_out_time)-strtotime($attendence_in_time);

					if ($seconds_diff<=0) {
						$this->return['error'] = array();

					   $this->return['common_error_msg'] = "Out time should be after In time";
					}
					else{
						$attendence_login_hours = gmdate("H:i:s", $seconds_diff);

						$upd_attendence_data = [
												  'attendence_in_time'     => $attendence_in_time,
												  'attendence_out_time'    => $attendence_out_time,
												  'attendence_login_hours' => $attendence_login_hours 
						                       ];

	                    if ($this->attendence_model->update_attendence($_attendence_id, $upd_attendence_data)) {

			            	$this->return['success'] = "Attendence updated successfully...";

							$this->return['close'] = TRUE;
			            }
			            else{
			            	$this->return['error'] = array();

							$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
			            }
					}

					foreach ($_POST as $post_key => $post_value) {
						$this->return['no_error'][$post_key] = NULL;
					}
				}
				else{

					$this->return['error'] = array();

					$this->return['error-a'] = $this->form_validation->error_array();

					$this->return['common_error_msg'] = "Please complete fields correctly...";

					foreach ($_POST as $each_post_key => $each_post_val) {
						$this->return['error'][$each_post_key] = form_error($each_post_key);
					}
				}		
			}
		}

		echo json_encode($this->return);
	}
	/********************************Edit Attendence End *************************************/




	/********************************Delete Attendence Modal Start ***********************************/
	public function delete_attendence_modal(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$_attendence_id = $this->input->post('_attendence_id');

		    $attendence_data = $this->attendence_model->attendence_list($this->session->userdata('_fin_year_id'),['_attendence_id' => $_attendence_id]);

		    if (!$attendence_data) {
			
				$this->return['error'] = "Invalid data given";
			}
			else{
				$this->return['success'] = TRUE;

				$this->return['modal_id'] = "delete-attendence-modal";

				$data['modal_id'] = "delete-attendence-modal";

				$data['modal_title'] = "Delete Attedence";

				$data['modal_body'] = "Are you sure to delete this attendence ?";

				$data['modal_link'] = "'attendence/delete-attendence'";

				$data['modal_data'] = "'_attendence_id=$_attendence_id'";

				$this->return['modal'] = $this->load->view('admin/xhr/confirm_delete_modal', $data, TRUE);
			}
		}

		echo json_encode($this->return);
	}
	/********************************Delete Attendence Modal End ***********************************/





	/********************************Delete Attendence Start ***********************************/
	public function delete_attendence(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$_attendence_id = $this->input->post('_attendence_id');

		    $attendence_data = $this->attendence_model->attendence_list($this->session->userdata('_fin_year_id'),['_attendence_id' => $_attendence_id]);

		    if (!$attendence_data) {
			
				$this->return['error'] = "Invalid data given";
			}
			else{
				if ($this->attendence_model->delete_attendence($_attendence_id)) {

					$this->return['success'] = "Attendence deleted successfully...";

					$this->return['close'] = TRUE;

					$this->return['modal_id'] = "delete-attendence-modal";
				}
				else{
					$this->return['error'] = "Some Problems Occured...Try Again Later";
				}
			}
		}

		echo json_encode($this->return);
	}
	/********************************Delete Attendence End ***********************************/




	/********************************Add Monthly Summary Modal Start ***********************************/
	public function add_monthly_summary_modal(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$this->return['success'] = TRUE;

			$this->load->model('user_model');

			$this->data['users'] = $this->user_model->user_list(['user_role_id' => 2]);
	
			$this->return['modal'] = $this->load->view('admin/xhr/attendence/add_monthly_summary_modal', $this->data, TRUE);

			$this->return['modal_id'] = "add-monthly-summary-modal";
		}

		echo json_encode($this->return);
	}
	/********************************Add Monthly Summary Modal End *************************************/





	/********************************Add Monthly Summary  Start ***********************************/
	public function add_monthly_summary(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "You are not authorized to access here !";
		}
		else{
			$this->form_validation->set_rules($this->admin_rules->add_monthly_summary());

			if ($this->form_validation->run()) {

				$attendence_summary_month = $this->input->post("attendence_summary_month");

				$attendence_summary_month = db_date_format("01-".$attendence_summary_month);

				$check_summary = $this->db->select("COUNT(_attendence_summary_id) AS count")
				                          ->from("attendence_summary")
				                          ->where("attendence_summary_fin_year_id", $this->session->userdata('_fin_year_id'))
				                          ->where("attendence_summary_user_id", $this->input->post("attendence_summary_user_id"))
				                          ->where("attendence_summary_month", $attendence_summary_month)
				                          ->get()
				                          ->row()
				                          ->count;

				if ($check_summary) {

				    $this->return['error'] = array();

					$this->return['common_error_msg'] = "Summary for this member in that month already added !";
				} 
				else{

					$add_monthly_summary = 
					[
						"attendence_summary_fin_year_id"   => $this->session->userdata('_fin_year_id'),
						"attendence_summary_user_id"       => $this->input->post("attendence_summary_user_id"),
						"attendence_summary_month"         => $attendence_summary_month,
						"attendence_summary_days_in_month" => $this->input->post("attendence_summary_days_in_month"),
						"attendence_summary_days_present"  => $this->input->post("attendence_summary_days_present"),
						"attendence_summary_days_absent"   => $this->input->post("attendence_summary_days_absent"),
						"attendence_summary_leave_taken"   => $this->input->post("attendence_summary_leave_taken"),
						"attendence_summary_late_count"    => $this->input->post("attendence_summary_late_count")

					];


					if ($this->attendence_model->add_summary($add_monthly_summary)) {


						//Send notification to team member start
						$notification_title = "Your attendence monthly summary for the month ".
						                       date('M Y', strtotime($attendence_summary_month))." has been uploaded";


                        $add_notification_data = 
                        [
						   "notification_to_user_id" => $this->input->post("attendence_summary_user_id"),
						   "notification_title"      => $notification_title,
						   "notification_from_user_id" => $this->session->userdata('_user_id'),
						   "notification_action_type"  => "link",
						   "notification_modal_link"    => "attendence/monthly-summary"
                        ]; 

                        $this->load->model('notification_model');

                        $this->notification_model->add_notification($add_notification_data);						                       
						//Send notification to team member end

		            	$this->return['success'] = "Attendence monthly summary added successfully...";

						$this->return['close'] = TRUE;
		            }
		            else{
		            	$this->return['error'] = array();

						$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
		            }
				}                         

				foreach ($_POST as $post_key => $post_value) {
					$this->return['no_error'][$post_key] = NULL;
				}
			}
			else{

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Please complete fields correctly...";

				foreach ($_POST as $each_post_key => $each_post_val) {
					$this->return['error'][$each_post_key] = form_error($each_post_key);
				}
			}	
		}

		echo json_encode($this->return);
	}
	/********************************Add Monthly Summary End **************************************/





	/******************************* Monthly Summary List Start ***********************************/
	public function monthly_summary_list(){

		$ctrl = $this->input->get('ctrl');

		$_user_id = $this->input->get('_user_id');

		if (!$_user_id && !in_array($this->session->userdata('user_role_id'), [1,3])) {
			$_user_id = $this->session->userdata('_user_id');
		}

		$request_data = $_REQUEST;

		$limit  = isset($request_data['length']) ? $request_data['length'] : 10;
		$offset = isset($request_data['start'])  ? $request_data['start']  : 0;


		// getting total number records without any search
		$data = $this->attendence_model->summary_list($this->session->userdata('_fin_year_id'),
					                                    [
						                                   'limit'    => $limit, 
						                                   'offset'   => $offset,
						                                   '_user_id' => $_user_id
				                                        ]
				                                      );

		$total_row_count = $this->attendence_model->summary_list($this->session->userdata('_fin_year_id'),
				                                                  [  'count' =>  1, '_user_id' => $_user_id]);	
		
		$total_filtered_count = $total_row_count;


		if (isset($request_data['search']['value']) && !empty($request_data['search']['value'])) {

			$data = $this->attendence_model->summary_list($this->session->userdata('_fin_year_id'),
						                                     [
									             	           'like'     => $request_data['search']['value'],
									             	           'limit'    => $limit,
									             	           'offset'   => $offset,
									             	           '_user_id' => $_user_id
										             	     ]);

			$total_filtered_count = count($this->attendence_model
				                               ->summary_list($this->session->userdata('_fin_year_id'),
				                                         	  [
                                                                'like'     => $request_data['search']['value'],
                                                                'order_by' => $order_by,
                                                                '_user_id' => $_user_id
                                                              ]));	
			
		}



		$final_data = [];


		if ($data) {
			foreach ($data as $i=> $each_data) {

				$nested_data = [];

				$nested_data[] = ($offset)+($i+1); 


				if ($ctrl=="attendence" && in_array($this->session->userdata('user_role_id'), [1,3])) {
					$nested_data[] = "<a href=\"../team-members/member-details/".$each_data->_user_id."\">
					                     <img src=\"".user_img($each_data->user_image, $each_data->user_gender)."\" 
					                          style=\"height:30px; width:30px;\" class=\"img-circle\">".
					                      $each_data->user_first_name." ".$each_data->user_last_name.
					                 "</a>";
				}


				$nested_data[] = $each_data->attendence_summary_month.'<br> ( '.$each_data->attendence_summary_days_present.' days )';	

				$nested_data[] = $each_data->attendence_summary_days_present.' day(s)';

				$nested_data[] = $each_data->attendence_summary_days_absent.' day(s)';

				$nested_data[] = $each_data->attendence_summary_leave_taken.' day(s)';

				$nested_data[] = $each_data->attendence_summary_late_count.' day(s)';

				$nested_data[] = $each_data->attendence_summary_avg_login_hours.' hour(s)';


				if ($each_data->attendence_summary_is_salary_slip_created) {
					
					$nested_data[] = "<span class=\"label label-success\">Processed</span>"; 
				}
				else{
					$nested_data[] = "<span class=\"label label-danger\">Not Processed</span>"; 
				}

				if ($ctrl=="attendence" && in_array($this->session->userdata('user_role_id'), [1,3])) {

					if ( $each_data->attendence_summary_is_salary_slip_created==0) {
						
						$nested_data[] = "<ul class=\"nav navbar-nav navbar-right\">
	                                    <li class=\"dropdown\">
	                    				<a href=\"javascript:void(0);\" class=\"dropdown-toggle\" 
	                    				   data-toggle=\"dropdown\">
	                    				   <i class=\"fa fa-cog\" ></i><b class=\"caret\"></b>
	                    				</a>
	                    				<ul class=\"dropdown-menu\">
	                      				  <li>
	                      				     <a href='javascript:void(0);' class='fa fa-pencil' style='color:#007bff;'
	                      				        onclick=\"open_modal('attendence/edit-monthly-summary', 
	                      				        '_attendence_summary_id=".$each_data->_attendence_summary_id."');\"> Edit
										     </a>
										  </li>
										  <li>
	                      				     <a href='javascript:void(0);' class='fa fa-inr' style='color:#000;'
	                      				        onclick=\"open_modal('attendence/generate-salary', 
	                      				        '_attendence_summary_id=".$each_data->_attendence_summary_id."');\"> Process Salary
										     </a>
										  </li>
										  <li>
	                      				     <a href='javascript:void(0);' class='fa fa-trash' style='color:#dc3545;'
	                      				        onclick=\"open_modal('attendence/delete-monthly-summary', 
	                      				        '_attendence_summary_id=".$each_data->_attendence_summary_id."');\"> Delete
										     </a>
										  </li>
	                    				</ul>
	                  					</li>
	                  				</ul>";
					}
					else{
						$nested_data[] = "";
					}
                	
                }


                $final_data[] =  $nested_data;
			}
		}	


		$json_data = array(
							"draw"            => intval(isset($request_data['draw']) ? $request_data['draw'] : 1),   
							"recordsTotal"    => intval( $total_row_count ),  
							"recordsFiltered" => intval( $total_filtered_count ), 
							"data"            => $final_data
						);

		echo json_encode($json_data);  // send data as json format		
	}
	/******************************* Monthly Summary List End *************************************/




	/******************************* Edit Monthly Summary Modal Start ***********************************/
	public function edit_monthly_summary_modal(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to acces here !";
		}
		else{
			$this->load->model('attendence_model');

    	    $_attendence_summary_id = $this->input->post('_attendence_summary_id');

		    $summary_data = $this->attendence_model->summary_list($this->session->userdata('_fin_year_id'),
		    	                                     ['_attendence_summary_id' => $_attendence_summary_id]);

		    if (!$summary_data) {
			
				$this->return['error'] = "Invalid data given";
			}
			elseif ($summary_data->attendence_summary_is_salary_slip_created==1) {

				$this->return['error'] = "You can't edit monthly summary after salary processed";
			}
			else{
				$this->return['success'] = TRUE;

				$this->load->model('user_model');

			    $this->data['users'] = $this->user_model->user_list(['user_role_id' => 2]);

				$this->data['summary_data'] = $summary_data;
	
				$this->return['modal'] = $this->load->view('admin/xhr/attendence/edit_monthly_summary_modal', $this->data, TRUE);

				$this->return['modal_id'] = "edit-monthly-summary-modal";
			}
		}

		echo json_encode($this->return); 
	}
	/******************************* Edit Monthly Summary Modal End ***********************************/



	/******************************* Edit Monthly Summary Start ***********************************/
	public function edit_monthly_summary(){

		/*error_reporting(-1);
		ini_set('display_errors', 1);*/

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "You are not authorized to access here !";
		}
		else{
			$this->load->model('attendence_model');

    	    $_attendence_summary_id = $this->input->post('_attendence_summary_id');

		    $summary_data = $this->attendence_model->summary_list($this->session->userdata('_fin_year_id'),
		    	                                     ['_attendence_summary_id' => $_attendence_summary_id]);

		    if (!$summary_data) {

				$this->return['error'] = array();

			    $this->return['common_error_msg'] = "Invalid data given";
			}
			elseif ($summary_data->attendence_summary_is_salary_slip_created==1) {

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "You can't edit monthly summary after salary processed";
			}
			else{
				$this->form_validation->set_rules($this->admin_rules->add_monthly_summary());

				if ($this->form_validation->run()) {


					$upd_monthly_summary = 
					[
						"attendence_summary_days_present"  => $this->input->post("attendence_summary_days_present"),
						"attendence_summary_days_absent"   => $this->input->post("attendence_summary_days_absent"),
						"attendence_summary_leave_taken"   => $this->input->post("attendence_summary_leave_taken"),
						"attendence_summary_late_count"    => $this->input->post("attendence_summary_late_count")

					];

					if ($this->attendence_model->update_summary($_attendence_summary_id, $upd_monthly_summary)) {


						//Send notification to team member start
						$notification_title = "Your attendence monthly summary for the month ".
						                       date('M Y', strtotime($summary_data->attendence_summary_month))." is updated";

                        $add_notification_data = 
                        [
						   "notification_to_user_id" => $summary_data->_user_id,
						   "notification_title"      => $notification_title,
						   "notification_from_user_id" => $this->session->userdata('_user_id'),
						   "notification_action_type"  => "link",
						   "notification_modal_link"    => "attendence/monthly-summary"
                        ]; 

                        $this->load->model('notification_model');

                        $this->notification_model->add_notification($add_notification_data);						                       
						//Send notification to team member end

						$this->return['success'] = "Attendence monthly summary updated successfully...";

						$this->return['close'] = TRUE;
					}
					else{
						$this->return['error'] = array();

						$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
					}	

					foreach ($_POST as $post_key => $post_value) {
						$this->return['no_error'][$post_key] = NULL;
					}
				}
				else{

					$this->return['error'] = array();

					//$this->return['sasa'] = $this->form_validation->error_array();

					$this->return['common_error_msg'] = "Please complete fields correctly...";

					foreach ($_POST as $each_post_key => $each_post_val) {
						$this->return['error'][$each_post_key] = form_error($each_post_key);
					}
				}	
			}
		}

		echo json_encode($this->return); 
	}
	/******************************* Edit Monthly Summary End *************************************/




	/******************************* Delete Monthly Summary Modal Start ************************************/
	public function delete_monthly_summary_modal(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$this->load->model('attendence_model');

    	    $_attendence_summary_id = $this->input->post('_attendence_summary_id');

		    $summary_data = $this->attendence_model->summary_list($this->session->userdata('_fin_year_id'),
		    	                                     ['_attendence_summary_id' => $_attendence_summary_id]);


		    if (!$summary_data) {

			    $this->return['error'] = "Invalid data given";
			}
			elseif ($summary_data->attendence_summary_is_salary_slip_created==1) {

				$this->return['error'] = "You can't deleted monthly summary after salary processed";
			}
			else{
				$this->return['success'] = TRUE;

				$this->return['modal_id'] = "delete-monthly-summary-modal";

				$data['modal_id'] = "delete-monthly-summary-modal";

				$data['modal_title'] = "Delete Monthly Summary";

				$data['modal_body'] = "Are you sure to delete this monthly summary ?";

				$data['modal_link'] = "'attendence/delete-monthly-summary'";

				$data['modal_data'] = "'_attendence_summary_id=$_attendence_summary_id'";

				$this->return['modal'] = $this->load->view('admin/xhr/confirm_delete_modal', $data, TRUE);
			}
		}


		echo json_encode($this->return); 
	}
	/******************************* Delete Monthly Summary Modal End **************************************/



	/******************************* Delete Monthly Summary Start ************************************/
	public function delete_monthly_summary(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$this->load->model('attendence_model');

    	    $_attendence_summary_id = $this->input->post('_attendence_summary_id');

		    $summary_data = $this->attendence_model->summary_list($this->session->userdata('_fin_year_id'),
		    	                                     ['_attendence_summary_id' => $_attendence_summary_id]);

		    if (!$summary_data) {

			    $this->return['error'] = "Invalid data given";
			}
			elseif ($summary_data->attendence_summary_is_salary_slip_created==1) {

				$this->return['error'] = "You can't deleted monthly summary after salary processed";
			}
			else{
				if ($this->attendence_model->delete_summary($_attendence_summary_id)) {

					$this->return['success'] = "Monthly summary deleted successfully...";

					$this->return['close'] = TRUE;

					$this->return['modal_id'] = "delete-monthly-summary-modal";
				}
				else{
					$this->return['error'] = "Some Problems Occured...Try Again Later";
				}
			}
		}

		echo json_encode($this->return); 
	}
	/******************************* Delete Monthly Summary End ************************************/




	/******************************* Generate Salary Modal Start ************************************/
	public function generate_salary_modal(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$this->load->model('attendence_model');

    	    $_attendence_summary_id = $this->input->post('_attendence_summary_id');

		    $summary_data = $this->attendence_model->summary_list($this->session->userdata('_fin_year_id'),
		    	                                     ['_attendence_summary_id' => $_attendence_summary_id]);


		    if (!$summary_data) {

			    $this->return['error'] = "Invalid data given";
			}
			elseif ($summary_data->attendence_summary_is_salary_slip_created==1) {

				$this->return['error'] = "You can't deleted monthly summary after salary processed";
			}
			else{
				$this->return['success'] = TRUE;

				$this->return['modal_id'] = "generate-salary-modal";

				$data['modal_id'] = "generate-salary-modal";

				$data['modal_title'] = "Process Salary";

				$data['modal_body'] = "Are you sure to process salary for this month ? This process can't be undone.";

				$data['modal_link'] = "'attendence/generate-salary'";

				$data['modal_data'] = "'_attendence_summary_id=$_attendence_summary_id'";

				$this->return['modal'] = $this->load->view('admin/xhr/confirm_delete_modal', $data, TRUE);
			}
		}


		echo json_encode($this->return); 
	}
	/****************************** Generate Salary Modal End ***************************************/




	/******************************* Generate Salary Start ************************************/
	public function generate_salary(){

		if (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			$this->load->model('attendence_model');

    	    $_attendence_summary_id = $this->input->post('_attendence_summary_id');

		    $summary_data = $this->attendence_model->summary_list($this->session->userdata('_fin_year_id'),
		    	                                     ['_attendence_summary_id' => $_attendence_summary_id]);


		    if (!$summary_data) {

			    $this->return['error'] = "Invalid data given";
			}
			elseif ($summary_data->attendence_summary_is_salary_slip_created==1) {

				$this->return['error'] = "You can't deleted monthly summary after salary processed";
			}
			else{
				$this->load->model('user_model');

				$salary_details = $this->user_model->salary_details($summary_data->_user_id, $this->session->userdata('_fin_year_id'));

				if (!$salary_details) {

					$this->return['error'] = "Salary is not added for this member in this financial year";
				}
				else{
					$this->load->model('salary_model');

					$multipler = $summary_data->attendence_summary_days_present/$summary_data->attendence_summary_days_in_month;
				                
					$add_salary_data = 
					[
					   "salary_slip_fin_year_id"          => $this->session->userdata('_fin_year_id'),
					   "salary_slip_user_id"              => $summary_data->_user_id,
					   "salary_slip_month"                => $summary_data->attendence_summary_month_val,	
					   "salary_slip_per_month"            => $salary_details->salary_total,
					   "salary_slip_basic"                => round(($salary_details->salary_basic)*$multipler),
					   "salary_slip_hra"                  => round(($salary_details->salary_hra)*$multipler),
					   "salary_slip_conveyance_allowance" => round(($salary_details->salary_conveyance_allowance)*$multipler),
					   "salary_slip_special_allowance"    => round(($salary_details->salary_special_allowance)*$multipler),
					   "salary_slip_work_from_home"       => round(($salary_details->salary_work_from_home)*$multipler),
					   "salary_slip_esic_employee"        => round(($salary_details->salary_esic_employee)*$multipler),
					   "salary_slip_pf_employee"          => round(($salary_details->salary_pf_employee)*$multipler),
					   "salary_slip_esic_employer"        => round(($salary_details->salary_esic_employer)*$multipler),
					   "salary_slip_pf_employer"          => round(($salary_details->salary_pf_employer)*$multipler),
					   "salary_slip_professional_tax"     => round(($salary_details->salary_professional_tax)*$multipler),
					   "salary_slip_tds"                  => round(($salary_details->salary_tds)*$multipler)
					];


					if ($_salary_slip_id = $this->salary_model->add_salary($add_salary_data)) {

						//Update Summary data start
						$upd_monthly_summary_data = 
						[
							"attendence_summary_is_salary_slip_created" => 1,
							"attendence_summary_salary_slip_id"         => $_salary_slip_id
						];

						$this->attendence_model->update_summary($_attendence_summary_id, $upd_monthly_summary_data);
						//Update Summary data end

		            	$this->return['success'] = "Salary processed successfully...";

						$this->return['close'] = TRUE;

						$this->return['modal_id'] = "generate-salary-modal";
		            }
		            else{
		            	$this->return['error'] = array();

						$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
		            } 
				}
			}
		}


		echo json_encode($this->return); 
	}
	/******************************* Generate Salary End **************************************/



}