<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Leave extends MY_Controller {

	public function __construct(){
		parent::__construct();

		if (!$this->input->is_ajax_request()) {
			$this->load->error_404($this->data);
		}

		$this->load->library('form_validation_rules/admin_rules');

		$this->load->model('leave_model');
	}




	/********************************Apply Leave Modal Start ***********************************/
	public function apply_leave_modal(){

		$this->load->model("user_model");

		$this->data['user_data'] = $this->user_model->user_list(['_user_id' => $this->session->userdata('_user_id')]);

		$this->return['success'] = TRUE;
	
		$this->return['modal'] = $this->load->view('admin/xhr/leave/apply_leave_modal', $this->data, TRUE);

		$this->return['modal_id'] = "apply-leave-modal";

		echo json_encode($this->return);
	}
	/********************************Apply Leave Modal End *************************************/




	/********************************Apply Leave Start ***********************************/
	public function apply_leave(){

		$this->load->model("user_model");

		$user_data = $this->user_model->user_list(['_user_id' => $this->session->userdata('_user_id')]);

		if (!isset($_POST['leave_duration'])) {
			$_POST['leave_duration'] = NULL;
		}

		if (!isset($_POST['leave_half_day'])) {
			$_POST['leave_half_day'] = NULL;
		}

		$casual_leave_start_date  = $this->settings_model->settings_by_key('casual_leave_start_date');
		$planned_leave_start_date = $this->settings_model->settings_by_key('planned_leave_start_date');

		$casual_leave_per_month   = $this->settings_model->settings_by_key('casual_leave_per_month');

		$this->form_validation->set_rules($this->admin_rules->apply_leave($this->input->post()));

		if ($this->form_validation->run()) {

			$current_fin_year = $this->settings_model->current_fin_year();

			$user_year_leave_balance = $user_data->user_year_leave_balance;

			$leave_no_of_days = 1;

			if ($this->input->post('leave_duration')=='half') {
				$leave_no_of_days = 0.5;
			}
			elseif ($this->input->post('leave_duration')=='multiple') {
				$leave_no_of_days = days_diff($this->input->post('leave_start_date'), $this->input->post('leave_end_date'));
			}


			if ($leave_no_of_days>$user_year_leave_balance) {
				$this->return['error'] = array();

				$this->return['common_error_msg'] = "You have only ".$user_year_leave_balance." leaves left";
			}
			elseif($leave_no_of_days<0){
				$this->return['error'] = array();

				$this->return['common_error_msg'] = "End date should be after start date ";
			}
			elseif($this->input->post('leave_type')=="casual" && 
				   days_diff(date("d-m-Y"),$this->input->post('leave_date')) < ($casual_leave_start_date+1)){

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Casual leave should be applied minimum ".$casual_leave_start_date." days in prior.";
			}
			elseif($this->input->post('leave_type')=="planned" && in_array($this->input->post('leave_duration'), ['half', 'single']) &&
				   days_diff(date("d-m-Y"),$this->input->post('leave_date')) < ($planned_leave_start_date+1)){

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Planned leave should be applied minimum 10 days in prior.";
			}
			elseif ($this->input->post('leave_type')=="planned" && $this->input->post('leave_duration')=="multiple" &&
					days_diff(date("d-m-Y"),$this->input->post('leave_start_date'))<($planned_leave_start_date+1)) {
			}
			elseif($this->input->post('leave_type')=="casual" &&  
		           ($this->leave_model->user_month_wise_cl_approved_count($current_fin_year->_fin_year_id, 
		           	$this->session->userdata('_user_id'), date('m', strtotime($this->input->post('leave_date'))))+$leave_no_of_days)>
		           $casual_leave_per_month){

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Maximum ".$casual_leave_per_month." CL is available in each month";
			}	
		    else{

		    	

		    	$add_leave_data = 
		    	[
	                'leave_fin_year_id' => $current_fin_year->_fin_year_id,
	                'leave_user_id'     => $this->session->userdata('_user_id'),
					'leave_type'        => $this->input->post('leave_type'),
					'leave_reason'      => $this->input->post('leave_reason'),
					'leave_duration'    => $this->input->post('leave_duration'),
					'leave_half_day'    => $this->input->post('leave_duration')=='half' ? $this->input->post('leave_half_day') : '0',
					'leave_start_date'  => $this->input->post('leave_date') ? 
					                       db_date_format($this->input->post('leave_date')) : 
					                       db_date_format($this->input->post('leave_start_date')),
                    'leave_end_date'    => $this->input->post('leave_end_date') ? 
					                       db_date_format($this->input->post('leave_end_date')) : 
					                       db_date_format($this->input->post('leave_date')),
					'leave_no_of_days'  => $leave_no_of_days,
					'leave_applied_by'  => $this->session->userdata('_user_id')                       					
	            ];


	            $leave_taken  = $user_data->user_yearly_leave-$user_data->user_year_leave_balance;

	            $leave_max_limit = leave_max_limit(date('n', strtotime($add_leave_data['leave_end_date'])));

	            if ( ($leave_taken+$leave_no_of_days) > $leave_max_limit) {
	            	
	            	$this->return['error'] = array();

					$this->return['common_error_msg'] = "You can't take more than ".$leave_max_limit." leave within ".
					                                    date('M Y', strtotime($add_leave_data['leave_end_date']));
	            }
	            elseif ($_leave_id = $this->leave_model->apply_leave($add_leave_data)) {


	            	//Send Notifications to all super admins start
	            	$admins = $this->db->select('_user_id')
			            	           ->from('users')
			            	           ->where('user_role_id', 1)
			            	           ->get()
			            	           ->result_array();

			        $admin_users = $admins ? array_column($admins, '_user_id') : array();
			        
			        if ($admin_users) {

			        	$this->load->model('notification_model');

			        	$notification_title = "Applied a ".ucwords($this->input->post('leave_type'))." leave on ".
			            	                  format_date($add_leave_data['leave_start_date']);

			        	if ($this->input->post('leave_duration')=='half') {
			            	    
		            	    $notification_title = "Applied a half day ".ucwords($this->input->post('leave_type'))." leave on ".
		            	                          format_date($add_leave_data['leave_start_date'])." in ".
		            	                          format_no($add_leave_data['leave_half_day'])." half";
		            	} 
		            	elseif ($this->input->post('leave_duration')=='multiple') {

		            	    $notification_title = "Applied ".$leave_no_of_days." day(s) ".ucwords($this->input->post('leave_type')).
		            	                          " leave from ".format_date($add_leave_data['leave_start_date'])." to ".
		            	                          format_date($add_leave_data['leave_end_date']);
		            	}

			            foreach ($admin_users as $key => $user_id) {

			            	$add_notification_data = 
	                        [
							   "notification_to_user_id" => $user_id,
							   "notification_title"      => $notification_title,
							   "notification_from_user_id" => $this->session->userdata('_user_id'),
							   "notification_action_type"  => "modal",
							   "notification_modal_id"    => "leave/view-application",
							   "notification_modal_data"  => "_leave_id=".$_leave_id 
	                        ]; 

	                        $this->notification_model->add_notification($add_notification_data);                    
			            }
			        } 
			        //Send Notifications to all super admins end   	           
	            	
	            	$this->return['success'] = "Leave applied successfully...";

					$this->return['close'] = TRUE;
	            }
	            else{
	            	$this->return['error'] = array();

					$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
	            } 
		    }

			foreach ($_POST as $post_key => $post_value) {
				$this->return['no_error'][$post_key] = NULL;
			}
		}
		else{

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Please complete fields correctly...";

			foreach ($_POST as $each_post_key => $each_post_val) {
				$this->return['error'][$each_post_key] = form_error($each_post_key);
			}
		}

		echo json_encode($this->return);	
	}
	/********************************Apply Leave End ***********************************/




	/********************************View Application Modal Start ***********************************/
	public function view_application_modal(){

		$_leave_id = $this->input->post('_leave_id');

		$leave_data = $this->leave_model->applications($this->session->userdata('_fin_year_id'), ['_leave_id' => $_leave_id]);


		if (!$leave_data) {
			
			$this->return['error'] = "Invalid data given";

		}
		else{
			$this->return['success'] = TRUE;

			$this->data['leave_data'] = $leave_data;

			$this->load->model("user_model");

			$this->data['user_data'] = $this->user_model->user_list(['_user_id' => $leave_data->_user_id]);
	
			$this->return['modal'] = $this->load->view('admin/xhr/leave/view_application_modal', $this->data, TRUE);

			$this->return['modal_id'] = "view-application-modal";
		}

		echo json_encode($this->return);
	}
	/********************************View Application Modal End *************************************/



	/********************************Approve Leave Start ***********************************/
	public function approve_leave(){

		$_leave_id = $this->input->post('_leave_id');

		$leave_data = $this->leave_model->applications($this->session->userdata('_fin_year_id'), ['_leave_id' => $_leave_id]);

		$current_fin_year = $this->settings_model->current_fin_year();

		$casual_leave_per_month = $this->settings_model->settings_by_key('casual_leave_per_month');

		if (!$leave_data) {
			
			$this->return['error'] = "Invalid data given";

		}
		elseif (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			if ($leave_data->leave_status!='pending') {

				$this->return['error'] = "This leave application already ".$leave_data->leave_status;
			}
			elseif (days_diff(web_date_format($leave_data->leave_end_date), date('d-m-Y'))<0) {

				$this->return['error'] = "You can approve the leave after ".format_date($leave_data->leave_end_date);
			}
			else{
				$this->load->model("user_model");

				$user_data = $this->user_model->user_list(['_user_id' => $leave_data->_user_id]);

				$leave_taken  = $user_data->user_yearly_leave-$user_data->user_year_leave_balance;

				$leave_max_limit = leave_max_limit(date('n', strtotime($leave_data->leave_end_date)));

				if ($leave_data->leave_no_of_days > $user_data->user_year_leave_balance) {

					$this->return['error'] = "Don't have enough leave balance to approve.";
				}
				elseif ($leave_data->leave_type=='casual' && 
			            ($this->leave_model->user_month_wise_cl_approved_count($current_fin_year->_fin_year_id, 
		           	     $leave_data->_user_id, date('m', strtotime($leave_data->leave_start_date)))+$leave_data->leave_no_of_days)>
			            $casual_leave_per_month) {
					
					$this->return['error'] = "Maximum ".$casual_leave_per_month." CL is available in each month";
				}
				elseif ( ($leave_taken+$leave_data->leave_no_of_days) > $leave_max_limit) {
	            	
	            	$this->return['error'] = "More than ".$leave_max_limit." leave within ".
					                                    date('M Y', strtotime($leave_data->leave_end_date))." is not allowed.";
	            }
				else{
					$upd_leave_data = [
										 'leave_status'       => 'approved',
										 'leave_updated_by'   => $this->session->userdata('_user_id'),
										 'leave_updated_time' => date('Y-m-d H:i:s')
					                  ];

	                if ($this->leave_model->update_application($_leave_id, $upd_leave_data)) {

	                	$upd_user_data = [
	                		               'user_year_leave_balance' => ($user_data->user_year_leave_balance-$leave_data->leave_no_of_days)
	                		             ];

                        $this->user_model->update_user($leave_data->_user_id, $upd_user_data);	  

                        //Send notification to team member start

                        $notification_title = "Your leave on ".format_date($leave_data->leave_start_date)." has been approved";

                        if ($leave_data->leave_duration=="half") {

                        	$notification_title = "Your half day leave on ".format_date($leave_data->leave_start_date).
                    	                          " in ".format_no($leave_data->leave_half_day)." half has been approved";                      
                        }
                        elseif ($leave_data->leave_duration=="multiple") {
                        	
                        	$notification_title = "Your ".$leave_data->leave_no_of_days." day(s) leave taken between ".
                        	                       format_date($leave_data->leave_start_date)." to ".
                        	                       format_date($leave_data->leave_end_date)." has been approved";
                        }

                        $add_notification_data = 
                        [
						   "notification_to_user_id" => $leave_data->_user_id,
						   "notification_title"      => $notification_title,
						   "notification_from_user_id" => $this->session->userdata('_user_id'),
						   "notification_action_type"  => "modal",
						   "notification_modal_id"    => "leave/view-application",
						   "notification_modal_data"  => "_leave_id=".$_leave_id 
                        ];  

                        $this->load->model('notification_model');

                        $this->notification_model->add_notification($add_notification_data);
                        //Send notification to team member end            		             

						$this->return['success'] = "Leave approved successfully...";

						$this->return['close'] = TRUE;

						$this->return['modal_id'] = "view-application-modal";
					}
					else{
						$this->return['error'] = "Some Problems Occured...Try Again Later";
					}
				}
			}
		}

		echo json_encode($this->return);
	}
	/********************************Approve Leave End *************************************/






	/********************************Reject Leave Start ***********************************/
	public function reject_leave(){

		$_leave_id = $this->input->post('_leave_id');

		$leave_data = $this->leave_model->applications($this->session->userdata('_fin_year_id'), ['_leave_id' => $_leave_id]);

		if (!$leave_data) {
			
			$this->return['error'] = "Invalid data given";

		}
		elseif (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{
			if ($leave_data->leave_status!='pending') {

				$this->return['error'] = "This leave application already ".$leave_data->leave_status;
			}
			else{
				$upd_leave_data = [
									 'leave_status'       => 'rejected',
									 'leave_updated_by'   => $this->session->userdata('_user_id'),
									 'leave_updated_time' => date('Y-m-d H:i:s')
				                  ];

                if ($this->leave_model->update_application($_leave_id, $upd_leave_data)) {

                	//Send notification to team member start
                	$notification_title = "Your leave on ".format_date($leave_data->leave_start_date)." is rejected";

                	if ($leave_data->leave_duration=="half") {

                    	$notification_title = "Your half day leave on ".format_date($leave_data->leave_start_date).
                    	                      " in ".format_no($leave_data->leave_half_day)." half is rejected";
                    }
                    elseif ($leave_data->leave_duration=="multiple") {
                    	
                    	$notification_title = "Your ".$leave_data->leave_no_of_days." day(s) leave between ".
                    	                       format_date($leave_data->leave_start_date)." to ".
                    	                       format_date($leave_data->leave_end_date)." is rejected";
                    }

                    $add_notification_data = 
                    [
					   "notification_to_user_id" => $leave_data->_user_id,
					   "notification_title"      => $notification_title,
					   "notification_from_user_id" => $this->session->userdata('_user_id'),
					   "notification_action_type"  => "modal",
					   "notification_modal_id"    => "leave/view-application",
					   "notification_modal_data"  => "_leave_id=".$_leave_id 
                    ]; 

                    $this->load->model('notification_model');

                    $this->notification_model->add_notification($add_notification_data);
                	//Send notification to team member end

					$this->return['success'] = "Leave rejected successfully...";

					$this->return['close'] = TRUE;

					$this->return['modal_id'] = "view-application-modal";
				}
				else{
					$this->return['error'] = "Some Problems Occured...Try Again Later";
				}
			}
		}

		echo json_encode($this->return);
	}
	/********************************Reject Leave End **************************************/




	/********************************Cancel Leave Start ***********************************/
	public function cancel_leave(){

		$_leave_id = $this->input->post('_leave_id');

		$leave_data = $this->leave_model->applications($this->session->userdata('_fin_year_id'), ['_leave_id' => $_leave_id]);

		if (!$leave_data) {
			
			$this->return['error'] = "Invalid data given";

		}
		else{
			if ($leave_data->leave_status!='pending') {

				$this->return['error'] = "This leave application already ".$leave_data->leave_status;
			}
			elseif ($leave_data->_user_id!=$this->session->userdata('_user_id') && 
				    !in_array($this->session->userdata('_user_id'), [1,3])) {
				
				$this->return['error'] = "You are not authrized to acces here !";
			}
			else{
				$upd_leave_data = [
									 'leave_status'       => 'cancelled',
									 'leave_updated_by'   => $this->session->userdata('_user_id'),
									 'leave_updated_time' => date('Y-m-d H:i:s')
				                  ];

                if ($this->leave_model->update_application($_leave_id, $upd_leave_data)) {

					$this->return['success'] = "Leave cancelled successfully...";

					$this->return['close'] = TRUE;

					$this->return['modal_id'] = "view-application-modal";
				}
				else{
					$this->return['error'] = "Some Problems Occured...Try Again Later";
				}

			}
		}

		echo json_encode($this->return);
	}
	/********************************Cancel Leave End ***********************************/




	/********************************Date by Leave Duration Start ***********************************/
	public function date_by_leave_duration(){

		$leave_duration = $this->input->post("leave_duration");
		$leave_type     = $this->input->post("leave_type");

		$this->return['success'] = TRUE;

		$this->return['leave_date_area'] = "";

		if ($leave_duration && $leave_type && in_array($leave_type, ['casual','planned']) && 
			in_array($leave_duration, ['half','single', 'multiple'])) {

			if ($leave_type=="casual" && $leave_duration=="multiple") {
				$this->return['leave_date_area'] = "";
			}
			else{
				$this->data['leave_type']     = $leave_type;
		   	    $this->data['leave_duration'] = $leave_duration;
	
			    $this->return['leave_date_area'] = $this->load->view('admin/xhr/leave/date_by_leave_duration', $this->data, TRUE);
			}
			
		}

		echo json_encode($this->return);
	}
	/********************************Date by Leave Duration End *************************************/



	/******************************* Applications Start ***********************************/
	public function applications(){

		$ctrl = $this->input->get('ctrl');

		$_user_id = $this->input->get('_user_id');

		if (!$_user_id && !in_array($this->session->userdata('user_role_id'), [1,3])) {
			$_user_id = $this->session->userdata('_user_id');
		}

		$request_data = $_REQUEST;

		$limit  = isset($request_data['length']) ? $request_data['length'] : 10;
		$offset = isset($request_data['start'])  ? $request_data['start']  : 0;


		// getting total number records without any search
		$data = $this->leave_model->applications($this->session->userdata('_fin_year_id'),
			                                     [
				                                   'limit'    => $limit, 
				                                   'offset'   => $offset,
				                                   '_user_id' => $_user_id
		                                         ]);

		$total_row_count = $this->leave_model->applications($this->session->userdata('_fin_year_id'),
			                                                [ 
				                                                'count'    =>  1,
				                                                '_user_id' => $_user_id
				                                            ]);	
		
		$total_filtered_count = $total_row_count;


		if (isset($request_data['search']['value']) && !empty($request_data['search']['value'])) {

			$data = $this->leave_model->applications($this->session->userdata('_fin_year_id'),
				                                     [
							             	           'like'     => $request_data['search']['value'],
							             	           'limit'    => $limit,
							             	           'offset'   => $offset,
							             	           '_user_id' => $_user_id
								             	     ]);

			$total_filtered_count = count($this->leave_model
				                               ->applications($this->session->userdata('_fin_year_id'),
				                                         	  [
                                                                'like'     => $request_data['search']['value'],
                                                                'order_by' => $order_by,
                                                                '_user_id' => $_user_id
                                                              ]));	
			
		}


		$final_data = [];


		if ($data) {
			foreach ($data as $i=> $each_data) {

				$nested_data = [];

				$nested_data[] = ($offset)+($i+1); 


				if ($ctrl=="leave" && in_array($this->session->userdata('user_role_id'), [1,3])) {
					$nested_data[] = "<a href=\"team-members/member-details/".$each_data->_user_id."\">
					                     <img src=\"".user_img($each_data->user_image, $each_data->user_gender)."\" 
					                          style=\"height:30px; width:30px;\" class=\"img-circle\">".
					                      $each_data->user_first_name." ".$each_data->user_last_name.
					                 "</a>";
				}


                $nested_data[] = ucwords($each_data->leave_type).' Leave';	

                $leave_date = format_date($each_data->leave_start_date);

                if ($each_data->leave_duration=="half") {
                	$leave_date = format_no($each_data->leave_half_day).' half on '.format_date($each_data->leave_start_date);
                }
                elseif ($each_data->leave_duration=="multiple") {
                	$leave_date = format_date($each_data->leave_start_date).
                	              "<br>to<br>".
                	              format_date($each_data->leave_end_date);
                }	
                
                $nested_data[] = $leave_date;			                 


                $nested_data[] = $each_data->leave_no_of_days;


                $label = "warning";

                if ($each_data->leave_status=='approved') {
                	$label = "success";
                }
                elseif ($each_data->leave_status=='rejected') {
                	$label = "danger";
                }
                elseif ($each_data->leave_status=='cancelled') {
                	$label = "default";
                }

                $nested_data[] = "<span class=\"label label-".$label."\">".ucwords($each_data->leave_status)."</span>"; 

                $nested_data[] = formatDate($each_data->leave_applied_time);

                if ($ctrl=="leave") {

                	$nested_data[] = "<a href='javascript:void;' class='fa fa-eye' title='Leave Application Details'
	                                     onclick=\"open_modal('leave/view-application', 
	                      				        '_leave_id=".$each_data->_leave_id."');\">
	                      		     </a>";
                }	

                

                $final_data[] =  $nested_data;
			}
			
		}
		

		$json_data = array(
							"draw"            => intval(isset($request_data['draw']) ? $request_data['draw'] : 1),   
							"recordsTotal"    => intval( $total_row_count ),  
							"recordsFiltered" => intval( $total_filtered_count ), 
							"data"            => $final_data
						);

		echo json_encode($json_data);  // send data as json format		
	}
	/******************************* Applications End **************************************/



}	