<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Projects extends My_Controller {

	public function __construct(){
		parent::__construct();

		if (!$this->input->is_ajax_request()) {
			$this->load->error_404($this->data);
		}

		$this->load->library('form_validation_rules/admin_rules');
		$this->load->model('projects_model');
	}

	public function project_list(){

		$request_data = $_REQUEST;

		$limit  = isset($request_data['length']) ? $request_data['length'] : 10;
		$offset = isset($request_data['start'])  ? $request_data['start']  : 0;

		// getting total number records without any search
		$data = $this->projects_model->projects([
			                                	'limit'    => $limit, 
			                                	'offset'   => $offset
	                                        ]);

		$total_row_count = $this->projects_model->projects([	'count' =>  1 ]);	
		
		$total_filtered_count = $total_row_count;

		if (isset($request_data['search']['value']) && !empty($request_data['search']['value'])) {

			$data = $this->projects_model->projects([
						             	           	'like'     => $request_data['search']['value'],
						             	           	'limit'    => $limit,
						             	           	'offset'   => $offset
							             	    ]);

			$total_filtered_count = count($this->projects_model
				                               ->projects([
                                                            'like'     => $request_data['search']['value'],
                                                            'order_by' => $order_by
                                                        ]));
		}

		$final_data = [];

		if ($data) {
			foreach ($data as $i=> $each_data) {

				$nested_data = [];

				$nested_data[] = ($offset)+($i+1);

				$title_section = '<a href="'.base_url("projects/details/".$each_data->_project_id).'">'.$each_data->project_title.'<br>';
				if($each_data->project_skills){
					$skill_names = skills_by_ids($each_data->project_skills);
					$skill_aray = explode(',', $skill_names);
					foreach($skill_aray as $skill_name){
						$title_section .= '<span class="badge badge-primary text-center">'.$skill_name.'</span>';
					}
				}
				$title_section .= '</a>';

				$nested_data[] = $title_section;

				$nested_data[] = '<a href="'.base_url("clients/details/".$each_data->_client_id).'">'.$each_data->client_name.'</a>';

				$nested_data[] = $each_data->project_price;

				$nested_data[] = format_date($each_data->project_start_date);

				$nested_data[] = format_date($each_data->project_deadline);

				$nested_data[] = project_status($each_data->project_status,TRUE);

				$nested_data[] ="<ul class=\"nav navbar-nav navbar-right\">
                                    <li class=\"dropdown\">
	                    				<a href=\"javascript:void(0);\" class=\"dropdown-toggle\" 
	                    				   data-toggle=\"dropdown\">
	                    				   <i class=\"fa fa-cog\" ></i><b class=\"caret\"></b>
	                    				</a>
	                    				<ul class=\"dropdown-menu\">
	                      				 	<li>
	                      				    	<a href='javascript:void(0);' class='fa fa-pencil' style='color:#007bff;'
	                      				        	onclick=\"open_modal('projects/edit-project', 
	                      				        	'_project_id=".$each_data->_project_id."');\"> Edit
										    	</a>
										  	</li>
										  	
	                    				</ul>
                  					</li>
                  				</ul>";

                $final_data[] =  $nested_data;  				
			}
		}

		$json_data = array(
							"draw"            => intval(isset($request_data['draw']) ? $request_data['draw'] : 1),   
							"recordsTotal"    => intval( $total_row_count ),  
							"recordsFiltered" => intval( $total_filtered_count ), 
							"data"            => $final_data
						);

		echo json_encode($json_data);  // send data as json format
	}

	public function add_project_modal(){
		$this->load->model('clients_model');
		$this->return['success'] 	= TRUE;

		$this->data['clients'] 		= $this->clients_model->clients();
		$this->data['skills'] 		= $this->settings_model->skills();

		$this->return['modal'] 		= $this->load->view('admin/xhr/projects/add_project_modal', $this->data, TRUE);
		$this->return['modal_id'] 	= "add-project-modal";

		echo json_encode($this->return);
	}

	public function add_project(){

		$this->form_validation->set_rules($this->admin_rules->add_project());

		if(!$this->input->post('project_skills')){
			$_POST['project_skills'] 					=	NULL;
		}
		if ($this->form_validation->run()) {

			if ($this->input->post('project_skills') && is_array($this->input->post('project_skills'))) {
				$project_skills = implode(',', $this->input->post('project_skills'));
			}
			else{
				$project_skills = NULL;
			}

			$project_data =	[
								'project_title'			=>	$this->input->post('project_title'),
								'project_client_id' 	=>	$this->input->post('project_client_id'),
								'project_description'	=>	$this->input->post('project_description'),
								'project_start_date'	=>	db_date_format($this->input->post('project_start_date')),
								'project_deadline'		=> 	db_date_format($this->input->post('project_deadline')),
								'project_price'			=> 	$this->input->post('project_price'),
								'project_skills'		=> 	$project_skills
			                ];

			if ($this->projects_model->add_project($project_data)) {
            	$this->return['success'] 				=	"Project added successfully...";
				$this->return['close'] 					=	TRUE;
            }
            else{
            	$this->return['error'] 					=	array();
				$this->return['common_error_msg'] 		=	"Some Problems Occured...Try Again Later";
            } 

            foreach ($_POST as $post_key => $post_value) {
				$this->return['no_error'][$post_key] 	=	NULL;
			}

			$this->return['no_error']['project_skills'] =	NULL;
		}
		else{
			$this->return['error'] 						=	array();
			$this->return['common_error_msg'] 			=	"Please complete fields correctly...";

			foreach ($_POST as $each_post_key => $each_post_val) {
				$this->return['error'][$each_post_key] 	=	form_error($each_post_key);
			}
			$this->return['error']['project_skills'] 	=	form_error('project_skills[]');
		}

		echo json_encode($this->return);
	}

	public function edit_project_modal(){
		
    	$_project_id 	= $this->input->post('_project_id');
		$project_data 	= $this->projects_model->projects(['_project_id' => $_project_id]);

		if (!$project_data) {
			$this->return['error'] = "Invalid data given";
		}
		else{
			$this->return['success'] 	= TRUE;
			$this->data['project_data'] = $project_data;
			$this->data['skills'] 		= $this->settings_model->skills();
			$this->return['modal'] 		= $this->load->view('admin/xhr/projects/edit_project_modal', $this->data, TRUE);
			$this->return['modal_id'] 	= "edit-project-modal";
		}

		echo json_encode($this->return);
	}

	public function edit_project(){
		$_project_id 	= $this->input->post('_project_id');
		$project_data 	= $this->projects_model->projects(['_project_id' => $_project_id]);
		if (!$project_data) {
			$this->return['error'] 							= array();
			$this->return['common_error_msg'] 				= "Invalid data given";
		}
		else{
			$this->form_validation->set_rules($this->admin_rules->edit_project());

			if(!$this->input->post('project_skills')){
				$_POST['project_skills'] 					=	NULL;
			}

			if ($this->form_validation->run()) {
				if ($this->input->post('project_skills') && is_array($this->input->post('project_skills'))) {
					$project_skills = implode(',', $this->input->post('project_skills'));
				}
				else{
					$project_skills = NULL;
				}

				$update_data =	[
									'project_title'			=>	$this->input->post('project_title'),
									'project_description'	=>	$this->input->post('project_description'),
									'project_start_date'	=>	db_date_format($this->input->post('project_start_date')),
									'project_deadline'		=> 	db_date_format($this->input->post('project_deadline')),
									'project_price'			=> 	$this->input->post('project_price'),
									'project_skills'		=> 	$project_skills,
									'project_status'		=>	$this->input->post('project_status')
				                ];

				if ($this->projects_model->update_project($_project_id,$update_data)) {
	            	$this->return['success'] 				=	"Project updated successfully...";
					$this->return['close'] 					=	TRUE;
	            }
	            else{
	            	$this->return['error'] 					=	array();
					$this->return['common_error_msg'] 		=	"Some Problems Occured...Try Again Later";
	            } 

	            foreach ($_POST as $post_key => $post_value) {
					$this->return['no_error'][$post_key] 	=	NULL;
				}

				$this->return['no_error']['project_skills'] =	NULL;
			}else{
				$this->return['error'] 						=	array();
				$this->return['common_error_msg'] 			=	"Please complete fields correctly...";

				foreach ($_POST as $each_post_key => $each_post_val) {
					$this->return['error'][$each_post_key] 	=	form_error($each_post_key);
				}
				$this->return['error']['project_skills'] 	=	form_error('project_skills[]');
			}
		}

		echo json_encode($this->return);
	}

	public function project_milestones(){
		$request_data = $_REQUEST;

		$limit  = isset($request_data['length']) ? $request_data['length'] : 10;
		$offset = isset($request_data['start'])  ? $request_data['start']  : 0;

    	$_project_id   = $this->input->post('_project_id');

    	// getting total number records without any search
		$data = $this->projects_model->milestones([
			                                	'limit'    		=> 	$limit, 
			                                	'offset'   		=> 	$offset,
			                                	'_project_id'	=>	$_project_id
	                                        ]);

		$total_row_count = $this->projects_model->milestones([	'count' 		=>  1,
			                                					'_project_id'	=>	$_project_id ]);	
		
		$total_filtered_count = $total_row_count;

		if (isset($request_data['search']['value']) && !empty($request_data['search']['value'])) {

			$data = $this->projects_model->milestones([
						             	           	'like'     		=> 	$request_data['search']['value'],
						             	           	'limit'    		=> 	$limit,
						             	           	'offset'  		=> 	$offset,
			                                		'_project_id'	=>	$_project_id
							             	    ]);

			$total_filtered_count = count($this->projects_model
				                               ->milestones([
                                                            'like'     		=> 	$request_data['search']['value'],
                                                            'order_by' 		=> 	$order_by,
			                                				'_project_id'	=>	$_project_id
                                                        ]));
		}

		$final_data = [];

		if ($data) {
			foreach ($data as $i=> $each_data) {

				$nested_data = [];

				$nested_data[] = ($offset)+($i+1); 

				$nested_data[] = format_date($each_data->milestone_due_date);

				$nested_data[] = $each_data->milestone_title;

				$nested_data[] = $each_data->milestone_description;

				$nested_data[] ="<ul class=\"nav navbar-nav navbar-right\">
                                    <li class=\"dropdown\">
	                    				<a href=\"javascript:void(0);\" class=\"dropdown-toggle\" 
	                    				   data-toggle=\"dropdown\">
	                    				   <i class=\"fa fa-cog\" ></i><b class=\"caret\"></b>
	                    				</a>
	                    				<ul class=\"dropdown-menu\">
	                      				 	<li>
	                      				    	<a href='javascript:void(0);' class='fa fa-pencil' style='color:#007bff;'
	                      				        	onclick=\"open_modal('projects/edit-milestone', 
	                      				        	'_milestone_id=".$each_data->_milestone_id."&_project_id=".$_project_id."');\"> Edit
										    	</a>
										  	</li>
	                    				</ul>
                  					</li>
                  				</ul>";

                $final_data[] =  $nested_data;  				
			}
		}

		$json_data = array(
							"draw"            => intval(isset($request_data['draw']) ? $request_data['draw'] : 1),   
							"recordsTotal"    => intval( $total_row_count ),  
							"recordsFiltered" => intval( $total_filtered_count ), 
							"data"            => $final_data
						);

		echo json_encode($json_data);  // send data as json format
	}

	public function add_milestone_modal(){
		$_project_id = $this->input->post('_project_id');
		$project_data 	= $this->projects_model->projects(['_project_id' => $_project_id]);

		if (!$project_data) {
			$this->return['error'] = "Invalid data given";
		}
		else{
			$this->return['success'] 	= TRUE;
			$this->data['project_data'] = $project_data;
			$this->return['modal'] 		= $this->load->view('admin/xhr/projects/add_milestone_modal', $this->data, TRUE);
			$this->return['modal_id'] 	= "add-milestone-modal";
		}

		echo json_encode($this->return);
	}

	public function add_milestone(){
		$_project_id = $this->input->post('_project_id');
		$project_data 	= $this->projects_model->projects(['_project_id' => $_project_id]);
		if (!$project_data) {
			$this->return['error'] 							= array();
			$this->return['common_error_msg'] 				= "Invalid data given";
		}
		else{
			$this->form_validation->set_rules($this->admin_rules->add_milestone());

			if ($this->form_validation->run()) {

				$milestone_data=[
									'milestone_title'		=>	$this->input->post('milestone_title'),
									'milestone_due_date'	=>	db_date_format($this->input->post('milestone_due_date')),
									'milestone_description'	=>	$this->input->post('milestone_description'),
									'milestone_project_id'	=>	$_project_id
								];

				if ($this->projects_model->add_milestone($milestone_data)) {
	            	$this->return['success'] 				=	"Milestone created successfully...";
					//$this->return['close'] 					=	TRUE;
					$this->return['reload']					=   TRUE;
	            }
	            else{
	            	$this->return['error'] 					=	array();
					$this->return['common_error_msg'] 		=	"Some Problems Occured...Try Again Later";
	            }
				$this->return['no_error'] 					=	array();
				foreach ($_POST as $post_key => $post_value) {
					$this->return['no_error'][$post_key] 	=	NULL;
				}
			}else{
				$this->return['error'] 						=	array();
				$this->return['common_error_msg'] 			=	"Please complete fields correctly...";

				foreach ($_POST as $each_post_key => $each_post_val) {
					$this->return['error'][$each_post_key] 	=	form_error($each_post_key);
				}
			}
		}
		echo json_encode($this->return);
	}

	public function edit_milestone_modal(){
		$_milestone_id 	= $this->input->post('_milestone_id');
		$milestone_data = $this->milestones_model->milestones(['_milestone_id' => $_milestone_id]);

		if (!$milestone_data) {
			$this->return['error'] = "Invalid data given";
		}
		else{
			$this->return['success'] 	= TRUE;
			$this->data['milestone_data'] = $milestone_data;
			$this->data['skills'] 		= $this->settings_model->skills();
			$this->return['modal'] 		= $this->load->view('admin/xhr/projects/edit_milestone_modal', $this->data, TRUE);
			$this->return['modal_id'] 	= "edit-milestone-modal";
		}

		echo json_encode($this->return);
	}

	public function add_member_modal(){
		$_project_id = $this->input->post('_project_id');
		$project_data 	= $this->projects_model->projects(['_project_id' => $_project_id]);

		if (!$project_data) {
			$this->return['error'] = "Invalid data given";
		}
		else{
			$this->load->model('user_model');
			$this->return['success'] 	= TRUE;
			$this->data['project_data'] = $project_data;
			$project_members = $this->projects_model->project_members([
																		'_project_id'	=> $_project_id,
																		'res_array'	 	=> TRUE
																	]);
			$this->data['project_members'] = $project_members?array_column($project_members, '_user_id'):array();
			$this->data['users']		= $this->user_model->user_list(['except_roles' => 10]);
			$this->return['modal'] 		= $this->load->view('admin/xhr/projects/add_member_modal', $this->data, TRUE);
			$this->return['modal_id'] 	= "add-member-modal";
		}

		echo json_encode($this->return);
	}

	public function add_member(){
		$_project_id = $this->input->post('_project_id');
		$project_data 	= $this->projects_model->projects(['_project_id' => $_project_id]);

		if (!$project_data) {
			$this->return['error'] 							= array();
			$this->return['common_error_msg'] 				= "Invalid data given";
		}
		else{
			if(!$this->input->post('project_members')){
				$_POST['project_members'] 					=	NULL;
			}
			$this->form_validation->set_rules($this->admin_rules->add_member());
			if($this->form_validation->run()){
				$project_members = [];
				foreach($this->input->post('project_members') as $key => $value){
					array_push($project_members,[
													'member_user_id'	=>	$value,
													'member_project_id'	=>	$_project_id
												]);
				}

				if(count($project_members) > 0){
					//$this->projects_model->delete_project_members($_project_id);
					if($this->projects_model->add_project_member_batch($project_members)){
						$this->return['success'] 			=	"Members added successfully...";
						//$this->return['close'] 				=	TRUE;
						$this->return['reload'] 				=	TRUE;
					}else{
						$this->return['error'] 				=	array();
						$this->return['common_error_msg'] 	=	"Some Problems Occured...Try Again Later";
					}
				}else{
					$this->return['error'] 				=	array();
					$this->return['common_error_msg'] 	=	"Some Problems Occured...Try Again Later";
				}

				$this->return['no_error'] 					=	array();
				foreach ($_POST as $post_key => $post_value) {
					$this->return['no_error'][$post_key] 	=	NULL;
				}
				$this->return['no_error']['project_members']=	NULL;

			}else{
				$this->return['error'] 						=	array();
				$this->return['common_error_msg'] 			=	"Please complete fields correctly...";

				foreach ($_POST as $each_post_key => $each_post_val) {
					$this->return['error'][$each_post_key] 	=	form_error($each_post_key);
				}
				$this->return['error']['project_members'] 	=	form_error('project_members[]');
			}
		}

		echo json_encode($this->return);
	}

	public function delete_member_modal(){

    	$_member_id = $this->input->post('_member_id');

		$member_data = $this->projects_model->project_members(['_member_id' => $_member_id]);

		if (!$member_data) {
			$this->return['error'] = "Invalid data given";
		}
		else{
			$this->return['success'] = TRUE;

			$this->return['modal_id'] = "delete-member-modal";

			$data['modal_id'] = "delete-member-modal";

			$data['modal_title'] = "Delete Member";

			$data['modal_body'] = "Are you sure to delete this member ?";

			$data['modal_link'] = "'projects/delete-member'";

			$data['modal_data'] = "'_member_id=$_member_id'";

			$this->return['modal'] = $this->load->view('admin/xhr/confirm_delete_modal', $data, TRUE);
		}

		echo json_encode($this->return);
	}

	public function delete_member(){
		$_member_id = $this->input->post('_member_id');

		$member_data = $this->projects_model->project_members(['_member_id' => $_member_id]);

		if (!$member_data) {
			$this->return['error'] 			= "Invalid data given";
		}else{
			if ($this->projects_model->delete_project_member($_member_id)) {

				$this->return['success'] 	= "Member deleted successfully...";

				$this->return['reload'] 	=	TRUE;

				$this->return['modal_id'] 	= "delete-member-modal";
			}
			else{
				$this->return['error'] 		= "Some Problems Occured...Try Again Later";
			}
		}

		echo json_encode($this->return);
	}
}