<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Settings extends MY_Controller {

	public function __construct(){
		parent::__construct();

		if (!$this->input->is_ajax_request()) {
			$this->load->error_404($this->data);
		}

		$this->load->library('form_validation_rules/admin_rules');

		if ($this->session->userdata('user_role_id')!=1) {

			$this->return['error'] = "You are not authorized to access here !";

			$this->return['common_error_msg'] = "You are not authorized to access here !";

			echo json_encode($this->return);

			exit();
		}
	}



	/********************************Set Financial Year Modal Start ***********************************/
	public function set_financial_year_modal(){

		$this->return['success'] = TRUE;

		$this->data['fin_years'] = $this->settings_model->fin_years();
	
		$this->return['modal'] = $this->load->view('admin/xhr/settings/set_financial_year_modal', $this->data, TRUE);

		$this->return['modal_id'] = "set-financial-year-modal";

		echo json_encode($this->return);
	}
	/********************************Set Financial Year Modal End ***********************************/



	/********************************Set Financial Year Start ***********************************/
	public function set_financial_year(){

		$this->form_validation->set_rules('_fin_year_id', 'Financial Year', 
			'required|trim|htmlspecialchars|check_val_exist[financial_year._fin_year_id]');


		if ($this->form_validation->run()) {

			$fin_year_data = $this->settings_model->fin_year_details($this->input->post('_fin_year_id'));

			$this->session->set_userdata('_fin_year_id', $fin_year_data->_fin_year_id);
			$this->session->set_userdata('fin_year', $fin_year_data->fin_year);

			$this->return['success'] = "Financial year updated successfully...";

			$this->return['reload'] = TRUE;

			$this->return['time'] = 2000;

			foreach ($_POST as $post_key => $post_value) {
				$this->return['no_error'][$post_key] = NULL;
			}
		}
		else{

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Please complete fields correctly...";

			foreach ($_POST as $each_post_key => $each_post_val) {
				$this->return['error'][$each_post_key] = form_error($each_post_key);
			}
		}

		echo json_encode($this->return);	
	}
	/********************************Set Financial Year End ***********************************/




	/********************************Update General Settings Start ***********************************/
	public function update_general_settings(){

		$upload_dir = "assets/images/upload/";

		$upload_logo_icon = TRUE;

		if (!empty($_FILES['logo_icon']['name'])) {

			$this->load->library('upload', image_upload_option($upload_dir), 'logo_icon_upload'); 
    		$this->logo_icon_upload->initialize(image_upload_option($upload_dir));

    		$upload_logo_icon = $this->logo_icon_upload->do_upload('logo_icon');
		}


		$upload_favicon = TRUE;
		
		if (!empty($_FILES['favicon']['name'])) {

			$this->load->library('upload', image_upload_option($upload_dir), 'favicon_upload'); 
    		$this->favicon_upload->initialize(image_upload_option($upload_dir));

    		$upload_favicon = $this->logo_icon_upload->do_upload('favicon');
		}




		$upload_logo_wide = TRUE;

		if (!empty($_FILES['logo_wide']['name'])) {

			$this->load->library('upload', image_upload_option($upload_dir), 'logo_wide_upload'); 
    		$this->logo_wide_upload->initialize(image_upload_option($upload_dir));

    		$upload_logo_wide = $this->logo_icon_upload->do_upload('logo_wide');
		}




		$upload_logo_transparent = TRUE;

		if (!empty($_FILES['logo_transparent']['name'])) {

			$this->load->library('upload', image_upload_option($upload_dir), 'logo_transparent_upload'); 
    		$this->logo_transparent_upload->initialize(image_upload_option($upload_dir));

    		$upload_logo_transparent = $this->logo_icon_upload->do_upload('logo_transparent');
		}


		$upload_logo_wide_transparent = TRUE;

		if (!empty($_FILES['logo_wide_transparent']['name'])) {

			$this->load->library('upload', image_upload_option($upload_dir), 'logo_wide_transparent_upload'); 
    		$this->logo_wide_transparent_upload->initialize(image_upload_option($upload_dir));

    		$upload_logo_wide_transparent = $this->logo_icon_upload->do_upload('logo_wide_transparent');
		}


		$upload_logo_transparent_big = TRUE;

		if (!empty($_FILES['logo_transparent_big']['name'])) {

			$this->load->library('upload', image_upload_option($upload_dir), 'logo_transparent_big_upload'); 
    		$this->logo_transparent_big_upload->initialize(image_upload_option($upload_dir));

    		$upload_logo_transparent_big = $this->logo_icon_upload->do_upload('logo_transparent_big');
		}


		$this->form_validation->set_rules($this->admin_rules->update_general_settings());

		if ($this->form_validation->run() && $upload_logo_icon && $upload_favicon && $upload_logo_wide && $upload_logo_transparent && 
	       $upload_logo_wide_transparent  && $upload_logo_transparent_big) {


			$general_settings = [];


			foreach ($_POST as $key => $value) {

				array_push($general_settings, array('settings_key' => $key,'settings_value' => $value));

				$this->return['no_error'][$key] = '';
			}


			if (!empty($_FILES['logo_icon']['name'])) {

	        	$row = [
	        			  'settings_key'   => 'logo_icon',
	        			  'settings_value' => $upload_dir.$this->logo_icon_upload->data()['file_name'];
	        	       ];

	        	array_push($general_settings, $row);       
	        }


	        if (!empty($_FILES['favicon']['name'])) {

	        	$row = [
	        			  'settings_key'   => 'favicon',
	        			  'settings_value' => $upload_dir.$this->favicon_upload->data()['file_name'];
	        	       ];

	        	array_push($general_settings, $row);       
	        }


	        if (!empty($_FILES['logo_wide']['name'])) {

	        	$row = [
	        			  'settings_key'   => 'favicon',
	        			  'settings_value' => $upload_dir.$this->logo_wide_upload->data()['file_name'];
	        	       ];

	        	array_push($general_settings, $row);       
	        }


	        if (!empty($_FILES['logo_transparent']['name'])) {

	        	$row = [
	        			  'settings_key'   => 'favicon',
	        			  'settings_value' => $upload_dir.$this->logo_transparent_upload->data()['file_name'];
	        	       ];

	        	array_push($general_settings, $row);       
	        }


	        if (!empty($_FILES['logo_wide_transparent']['name'])) {

	        	$row = [
	        			  'settings_key'   => 'favicon',
	        			  'settings_value' => $upload_dir.$this->logo_wide_transparent_upload->data()['file_name'];
	        	       ];

	        	array_push($general_settings, $row);       
	        }


	        if (!empty($_FILES['logo_transparent_big']['name'])) {

	        	$row = [
	        			  'settings_key'   => 'favicon',
	        			  'settings_value' => $upload_dir.$this->logo_transparent_big_upload->data()['file_name'];
	        	       ];

	        	array_push($general_settings, $row);       
	        }


			if($this->settings_model->update_settings_batch($general_settings)){

				$this->return['success'] = "General settings updated successfully...";

				$this->return['reload'] = TRUE;

				$this->return['time']	= 2000;

			}
			else{

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Nothing to update";
			}
		}
		else{

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Please complete fields correctly...";

			foreach ($_POST as $each_post_key => $each_post_val) {
				$this->return['error'][$each_post_key] = form_error($each_post_key);
			}

			if (!empty($_FILES['logo_icon']['name'])) {
				$this->return['error']['logo_icon']  = $this->logo_icon_upload->display_errors("<p style='color:red'>", "<p>");
			}

			if (!empty($_FILES['favicon']['name'])) {
				$this->return['error']['favicon']  = $this->favicon_upload->display_errors("<p style='color:red'>", "<p>");
			}

			if (!empty($_FILES['logo_wide']['name'])) {
				$this->return['error']['logo_wide']  = $this->logo_wide_upload->display_errors("<p style='color:red'>", "<p>");
			}

			if (!empty($_FILES['logo_transparent']['name'])) {
				$this->return['error']['logo_transparent']  = $this->logo_transparent_upload->display_errors("<p style='color:red'>", "<p>");
			}

			if (!empty($_FILES['logo_wide_transparent']['name'])) {
				$this->return['error']['logo_wide_transparent']  = $this->logo_wide_transparent_upload->display_errors("<p style='color:red'>", "<p>");
			}

			if (!empty($_FILES['logo_transparent_big']['name'])) {
				$this->return['error']['logo_transparent_big']  = $this->logo_transparent_big_upload->display_errors("<p style='color:red'>", "<p>");
			}
		}

		echo json_encode($this->return);	
	}	
	/********************************Update General Settings End ***********************************/



	/********************************Update Company Settings Start ***********************************/
	public function update_company_settings(){

		$this->form_validation->set_rules($this->admin_rules->update_company_settings());

		if ($this->form_validation->run()) {

			$company_settings = [];


			foreach ($_POST as $key => $value) {

				array_push($company_settings, array('settings_key' => $key,'settings_value' => $value));

				$this->return['no_error'][$key] = '';

			}

			if($this->settings_model->update_settings_batch($company_settings)){

				$this->return['success'] = "Company settings updated successfully...";

				$this->return['reload'] = TRUE;

				$this->return['time']	= 2000;

			}
			else{

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Nothing to update";
			}
		}
		else{

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Please complete fields correctly...";

			foreach ($_POST as $each_post_key => $each_post_val) {
				$this->return['error'][$each_post_key] = form_error($each_post_key);
			}
		}

		echo json_encode($this->return);	
	}
	/********************************Update Company Settings End ***********************************/





	/********************************Update Mail Settings Start ***********************************/
	public function update_mail_settings(){

		$this->form_validation->set_rules($this->admin_rules->update_mail_settings());

		if ($this->form_validation->run()) {

			$mail_settings = [];

			$mail_data = [];

			foreach ($_POST as $key => $value) {

				array_push($mail_settings, array('settings_key' => $key,'settings_value' => $value));

				$this->return['no_error'][$key] = '';

				$mail_data[$key] = $value;

			}

			$this->load->library('mail_format');

			if ($this->mail_format->mail_testing($mail_data)) {

				unset($mail_settings['mail_testing']);

				if($this->settings_model->update_settings_batch($mail_settings)){

					$this->return['success'] = "Mail settings updated successfully...";

					$this->return['reload'] = TRUE;

					$this->return['time']	= 2000;

				}
				else{

					$this->return['error'] = array();

					$this->return['common_error_msg'] = "Nothing to update";
				}
            }
            else{
            	$this->return['error'] = array();

				$this->return['common_error_msg'] = $this->mail_format->php_mailer->ErrorInfo;
            }
			 
		}
		else{

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Please complete fields correctly...";

			foreach ($_POST as $each_post_key => $each_post_val) {
				$this->return['error'][$each_post_key] = form_error($each_post_key);
			}
		}

		echo json_encode($this->return);	
	}
	/********************************Update Mail Settings End ***********************************/




	/********************************Update Leave Settings Start ***********************************/
	public function update_leave_settings(){

		$this->form_validation->set_rules($this->admin_rules->update_leave_settings());

		if ($this->form_validation->run()) {

			$leave_settings = [];


			foreach ($_POST as $key => $value) {

				array_push($leave_settings, array('settings_key' => $key,'settings_value' => $value));

				$this->return['no_error'][$key] = '';

			}

			if($this->settings_model->update_settings_batch($leave_settings)){

				$this->return['success'] = "Leave settings updated successfully...";

				$this->return['reload'] = TRUE;

				$this->return['time']	= 2000;

			}
			else{

				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Nothing to update";
			}
			 
		}
		else{

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Please complete fields correctly...";

			foreach ($_POST as $each_post_key => $each_post_val) {
				$this->return['error'][$each_post_key] = form_error($each_post_key);
			}
		}

		echo json_encode($this->return);
	}
	/********************************Update Leave Settings End ***********************************/

}	