<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Team_members extends MY_Controller {

	public function __construct(){
		parent::__construct();

		if (!$this->input->is_ajax_request()) {
			$this->load->error_404($this->data);
		}

		$this->load->model('user_model');

		$this->load->library('form_validation_rules/admin_rules');
	}



	/******************************* Add Member Modal Start ***********************************/
	public function add_member_modal(){

		$this->return['success'] = TRUE;

		$this->data['skills'] = $this->settings_model->skills();

		$this->data['user_roles'] = $this->db->from('user_roles')
		                                     ->where('_urole_id!=10', NULL, FALSE)
		                                     ->get()
		                                     ->result();
	
		$this->return['modal'] = $this->load->view('admin/xhr/team-members/add_member_modal', $this->data, TRUE);

		$this->return['modal_id'] = "add-member-modal";

		echo json_encode($this->return);
	}
	/******************************* Add Member Modal End ***********************************/




	/******************************* Add Member Start ***********************************/
	public function add_member(){

		if (!isset($_POST['user_gender'])) {
			$_POST['user_gender'] = NULL;
		}

		$this->form_validation->set_rules($this->admin_rules->add_team_member());

		if ($this->form_validation->run()) {

			$user_yearly_leave = 0;

			$user_skills = implode(',', $this->input->post('user_skills'));

			$add_member_data = 
			[
			    'user_first_name'         => $this->input->post('user_first_name'),
				'user_last_name'          => $this->input->post('user_last_name'),
				'user_email'              => $this->input->post('user_email'),
				'user_mobile'             => $this->input->post('user_mobile'),
				'user_alternate_phone'    => $this->input->post('user_alternate_phone'),
				'user_gender'             => $this->input->post('user_gender'),
				'user_dob'                => db_date_format($this->input->post('user_dob')),
				'user_address'            => $this->input->post('user_address'),
				'user_alternate_address'  => $this->input->post('user_alternate_address'),

				'user_job_title'          => $this->input->post('user_job_title'),
				'user_date_of_joining'    => db_date_format($this->input->post('user_date_of_joining')),
				'user_role_id'            => $this->input->post('user_role_id'),	
				'user_hourly_cost'        => $this->input->post('user_hourly_cost'),
				'user_emp_code'           => $this->input->post('user_emp_code'),
				'user_pan'                => $this->input->post('user_pan'),
				'user_skills'             => $user_skills,
				'user_yearly_leave'       => $this->input->post('user_yearly_leave'),
				'user_year_leave_balance' => $this->input->post('user_yearly_leave'),

				'user_password'           => 1234

           ];


			$this->load->model('user_model'); 
			

			if ($this->user_model->add_user($add_member_data)) {

            	$this->return['success'] = "Member registered successfully...";

				$this->return['close'] = TRUE;

				$this->return['reload'] = TRUE;

				$this->return['time'] = 1000;
            }
            else{
            	$this->return['error'] = array();

				$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
            } 


            foreach ($_POST as $post_key => $post_value) {
				$this->return['no_error'][$post_key] = NULL;
			} 
		}
		else{

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Please complete fields correctly...";

			foreach ($_POST as $each_post_key => $each_post_val) {
				$this->return['error'][$each_post_key] = form_error($each_post_key);
			}
		}

		echo json_encode($this->return);	
	}
	/******************************* Add Member End ***********************************/



	/******************************* Team Member List Start ***********************************/
	public function team_member_list(){

		$request_data = $_REQUEST;

		$limit  = isset($request_data['length']) ? $request_data['length'] : 10;
		$offset = isset($request_data['start'])  ? $request_data['start']  : 0;


		$online_badge = " <i class=\"fa fa-circle\" style=\"color: #5cb85c; font-size:10px;\"></i>";
		$away_badge   = " <i class=\"fa fa-clock-o\" style=\"color: #f2b33f; font-size:10px;\"></i>";
		$logout_badge =" <i class=\"fa fa-power-off\" style=\"color: #d9534f; font-size:10px;\"></i>";


		// getting total number records without any search
		$data = $this->user_model->user_list([
			                                   'limit'    => $limit, 
			                                   'offset'   => $offset
	                                         ]);

		$total_row_count = $this->user_model->user_list([ 
			                                                'count' =>  1
			                                            ]);	
		
		$total_filtered_count = $total_row_count;


		if (isset($request_data['search']['value']) && !empty($request_data['search']['value'])) {

			$data = $this->user_model->user_list([
						             	           'like'     => $request_data['search']['value'],
						             	           'limit'    => $limit,
						             	           'offset'   => $offset
							             	     ]);

			$total_filtered_count = count($this->user_model
				                               ->user_list([
                                                                'like'     => $request_data['search']['value']
                                                           ]));	
			
		}


		$final_data = [];


		if ($data) {
			foreach ($data as $i=> $each_data) {

				$user_badge = NULL;

				if ($each_data->_token_id) {

					$last_access_time = $each_data->token_last_access;

					$current_time = date('Y-m-d H:i:s', time());

					$time_diff = seconds_diff($last_access_time, $current_time);

					if ($time_diff>300) {
						$user_badge = $away_badge;
					}
					else{
						$user_badge = $online_badge;
					}
				}	

				$nested_data = [];

				$nested_data[] = ($offset)+($i+1); 

				$nested_data[] = "<a href=\"team-members/member-details/".$each_data->_user_id."\">
				                     <img src=\"".user_img($each_data->user_image, $each_data->user_gender)."\" 
				                          style=\"height:30px; width:30px;\" class=\"img-circle\">".
				                      $each_data->user_first_name." ".$each_data->user_last_name.$user_badge.
				                 "</a>";

				$nested_data[] = $each_data->user_job_title;

				$nested_data[] = "<a href=\"mailto:".$each_data->user_email."\">".$each_data->user_email."</a>";


				if (is_numeric($each_data->user_mobile) && strlen($each_data->user_mobile)==10) {
					
					$nested_data[] = "<a href=\"https://wa.me/91".$each_data->user_mobile."\" target=\"_blank\">".
					                    "<i class=\"fa fa-whatsapp\" style=\"color:#25d366;\"></i> ".$each_data->user_mobile.
					                 "</a>";
				}
				else{
					$nested_data[] = $each_data->user_mobile;
				}


                $final_data[] =  $nested_data; 

			}
		}


		$json_data = array(
							"draw"            => intval(isset($request_data['draw']) ? $request_data['draw'] : 1),   
							"recordsTotal"    => intval( $total_row_count ),  
							"recordsFiltered" => intval( $total_filtered_count ), 
							"data"            => $final_data
						);

		echo json_encode($json_data);  // send data as json format			
	}
	/******************************* Team Member List End *************************************/




	/********************************Update General Info Start ***********************************/
	public function update_general_info(){

		$_user_id = $this->input->post('user_id') ? $this->input->post('user_id') : $this->session->userdata('_user_id');

		if (!$_user_id) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Invalid data given";
		}
		elseif (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "You are not authorized to access here !";
		}
		else{

			$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);

			if (!$user_data) {
				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Invalid data given";
			}
			else{

				if (!isset($_POST['user_gender'])) {
					$_POST['user_gender'] = NULL;
				}

				$this->form_validation->set_rules($this->admin_rules->update_general_info($_user_id));

				if ($this->form_validation->run()) {


					$upd_user_data = [
										'user_first_name'        => $this->input->post('user_first_name'),
										'user_last_name'         => $this->input->post('user_last_name'),
										'user_dob'               => db_date_format($this->input->post('user_dob')),
										'user_gender'            => $this->input->post('user_gender'),
										'user_email'             => $this->input->post('user_email'),
										'user_mobile'            => $this->input->post('user_mobile'),
										'user_alternate_phone'   => $this->input->post('user_alternate_phone'),
										'user_address'           => $this->input->post('user_address'),
										'user_alternate_address' => $this->input->post('user_alternate_address')

					                 ];


                    if ($this->user_model->update_user($_user_id, $upd_user_data)) {

		            	$this->return['success'] = "General info updated successfully...";

		            	$this->return['not_disabled'] = TRUE;
		            }
		            else{
		            	$this->return['error'] = array();

						$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
		            }


					foreach ($_POST as $post_key => $post_value) {
						$this->return['no_error'][$post_key] = NULL;
					}
				}
				else{

					$this->return['error'] = array();

					$this->return['common_error_msg'] = "Please complete fields correctly...";

					foreach ($_POST as $each_post_key => $each_post_val) {
						$this->return['error'][$each_post_key] = form_error($each_post_key);
					}
				}	
			}

		}
		
		echo json_encode($this->return);	
	}
	/********************************Update General Info End ***********************************/



	/********************************Delete Member Modal Start ***********************************/
	public function delete_member_modal(){		

    	$_user_id = $this->input->post('_user_id');

		$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);


		if (!$user_data) {
			
			$this->return['error'] = "Invalid data given";

		}
		else{
			$this->return['success'] = TRUE;

			$this->return['modal_id'] = "delete-member-modal";

			$data['modal_id'] = "delete-member-modal";

			$data['modal_title'] = "Delete Member";

			$data['modal_body'] = "Are you sure to delete this member ?";

			$data['modal_link'] = "'team-members/delete-member'";

			$data['modal_data'] = "'_user_id=$_user_id'";

			$this->return['modal'] = $this->load->view('admin/xhr/confirm_delete_modal', $data, TRUE);
		}

		echo json_encode($this->return);
	}
	/********************************Delete Member Modal End ***********************************/



	/********************************Delete Member Start ***********************************/
	public function delete_member(){

    	$_user_id = $this->input->post('_user_id');

		$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);


		if (!$user_data) {
			
			$this->return['error'] = "Invalid data given";
		}
		else{
			if ($this->user_model->update_user($_user_id, ['user_is_delete' => 1])) {

				$this->return['success'] = "Member deleted successfully...";

				$this->return['close'] = TRUE;

				$this->return['modal_id'] = "delete-member-modal";
			}
			else{
				$this->return['error'] = "Some Problems Occured...Try Again Later";
			}
		}

		echo json_encode($this->return);

    }
	/********************************Delete Member End ***********************************/



	/********************************JOB Info Start ***********************************/
	public function job_info(){

		$_user_id = $this->input->post('user_id') ? $this->input->post('user_id') : $this->session->userdata('_user_id');

		if (!$_user_id) {
			$this->return['error'] = "Invalid data given";
		}
		else{

			$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);

			if (!$user_data) {
				$this->return['error'] = "Invalid data given";
			}
			else{

				$job_info = [
								'user_job_title'       => $user_data->user_job_title,
								'user_hourly_cost'     => $user_data->user_hourly_cost,
								'user_yearly_leave'    => $user_data->user_yearly_leave,
								'user_skills'          => $user_data->user_skills,
								'user_date_of_joining' => web_date_format($user_data->user_date_of_joining),
								'user_emp_code'        => $user_data->user_emp_code,
								'user_pan'             => $user_data->user_pan
				            ];

				$this->return['success'] = TRUE;

				$this->return['data'] = TRUE;

				$this->return['details'] = $job_info;
			}
		}
		

		echo json_encode($this->return);	
	}
	/********************************JOB Info End *************************************/





	/********************************Update JOB Info Start ***********************************/
	public function update_job_info(){

		$_user_id = $this->input->post('user_id') ? $this->input->post('user_id') : $this->session->userdata('_user_id');


		if (!$_user_id) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Invalid data given";
		}
		elseif (!in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "You are not authorized to access here !";
		}
		else{

			$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);

			if (!$user_data) {
				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Invalid data given";
			}
			else{
				$this->form_validation->set_rules($this->admin_rules->update_job_info($_user_id));

				if ($this->form_validation->run()) {

					$user_skills = implode(',', $this->input->post('user_skills'));

					$upd_user_data = [
										'user_job_title'       => $this->input->post('user_job_title'),
										'user_hourly_cost'     => $this->input->post('user_hourly_cost'),
										'user_yearly_leave'    => $this->input->post('user_yearly_leave'),
										'user_skills'          => $user_skills,
										'user_date_of_joining' => db_date_format($this->input->post('user_date_of_joining')),
										'user_emp_code'        => $this->input->post('user_emp_code'),
										'user_pan'             => $this->input->post('user_pan')
					                 ];


                     if ($this->user_model->update_user($_user_id, $upd_user_data)) {

		            	$this->return['success'] = "JOB info updated successfully...";

		            	$this->return['not_disabled'] = TRUE;
		            }
		            else{
		            	$this->return['error'] = array();

						$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
		            }


					foreach ($_POST as $post_key => $post_value) {
						$this->return['no_error'][$post_key] = NULL;
					}

				}
				else{

					$this->return['error'] = array();

					$this->return['common_error_msg'] = "Please complete fields correctly...";

					foreach ($_POST as $each_post_key => $each_post_val) {
						$this->return['error'][$each_post_key] = form_error($each_post_key);
					}

					$this->return['error']['user_skills'] = form_error('user_skills[]');
				}	
			}

		}	

		echo json_encode($this->return);
	}
	/********************************Update JOB Info End *************************************/





	/********************************Bank Details Start ***********************************/
	public function bank_details(){

		$_user_id = $this->input->post('user_id') ? $this->input->post('user_id') : $this->session->userdata('_user_id');

		if (!$_user_id) {
			$this->return['error'] = "Invalid data given";
		}
		elseif ($_user_id!=$this->session->userdata('_user_id') && !in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{

			$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);

			if (!$user_data) {
				$this->return['error'] = "Invalid data given";
			}
			else{
				$user_bank_details = (object)$this->user_model->bank_details($_user_id);

				$user_bank_details->bank_user_id = $_user_id;

				$this->return['success'] = TRUE;

				$this->return['data'] = TRUE;

				$this->return['details'] = $user_bank_details;
			}
		}

		echo json_encode($this->return);
	}
	/********************************Bank Details End *************************************/





	/********************************Update Bank Details Start ***********************************/
	public function update_bank_details(){

		$_user_id = $this->input->post('user_id') ? $this->input->post('user_id') : $this->session->userdata('_user_id');

		if (!$_user_id) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Invalid data given";
		}
		elseif ($this->session->userdata('user_role_id')!=1) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "You are not authorized to access here !";
		}
		else{

			$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);

			if (!$user_data) {
				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Invalid data given";
			}
			else{
				$this->form_validation->set_rules($this->admin_rules->update_bank_details($_user_id));

				if ($this->form_validation->run()) {

					$bank_data = 
					[
					  'bank_account_no'   => $this->input->post('bank_account_no'),
					  'bank_name'         => $this->input->post('bank_name'),
					  'bank_branch_name'  => $this->input->post('bank_branch_name'),
					  'bank_ifsc_code'    => $this->input->post('bank_ifsc_code')

	               ];

					if ($this->user_model->update_bank_details($_user_id, $bank_data)) {

	                	$this->return['success'] = "Bank details updated successfully...";

	                	$this->return['not_disabled'] = TRUE;
	                }
	                else{
		            	$this->return['error'] = array();

						$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
		            }

					foreach ($_POST as $post_key => $post_value) {
						$this->return['no_error'][$post_key] = NULL;
					}
				}
				else{

					$this->return['error'] = array();

					$this->return['common_error_msg'] = "Please complete fields correctly...";

					foreach ($_POST as $each_post_key => $each_post_val) {
						$this->return['error'][$each_post_key] = form_error($each_post_key);
					}
				}	
			}
		}

		echo json_encode($this->return);
	}
	/********************************Update Bank Details End ***********************************/





	/********************************Salary Details Start ***********************************/
	public function salary_details(){

		$_user_id = $this->input->post('user_id') ? $this->input->post('user_id') : $this->session->userdata('_user_id');

		if (!$_user_id) {
			$this->return['error'] = "Invalid data given";
		}
		elseif ($_user_id!=$this->session->userdata('_user_id') && !in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{

			$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);

			if (!$user_data) {
				$this->return['error'] = "Invalid data given";
			}
			else{
				$salary_details = (object)$this->user_model->salary_details($_user_id, $this->session->userdata('_fin_year_id'));

				$salary_details->salary_user_id = $_user_id;

				$this->return['success'] = TRUE;

				$this->return['data'] = TRUE;

				$this->return['details'] = $salary_details;
			}
		}

		echo json_encode($this->return);
	}
	/********************************Salary Details End **************************************/




	/********************************Update Salary Details Start ***********************************/
	public function update_salary_details(){

		$_user_id = $this->input->post('user_id') ? $this->input->post('user_id') : $this->session->userdata('_user_id');

		if (!$_user_id) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "Invalid data given";
		}
		elseif ($this->session->userdata('user_role_id')!=1) {

			$this->return['error'] = array();

			$this->return['common_error_msg'] = "You are not authorized to access here !";
		}
		else{

			$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);

			if (!$user_data) {
				$this->return['error'] = array();

				$this->return['common_error_msg'] = "Invalid data given";
			}
			else{
				$this->form_validation->set_rules($this->admin_rules->update_salary_details());

				if ($this->form_validation->run()) {

					$salary_data = 
					[
					  'salary_total'                => $this->input->post('salary_total'),
					  'salary_basic'                => $this->input->post('salary_basic'),
					  'salary_hra'                  => $this->input->post('salary_hra'),
					  'salary_conveyance_allowance' => $this->input->post('salary_conveyance_allowance'),
					  'salary_special_allowance'    => $this->input->post('salary_special_allowance'),
					  'salary_work_from_home'       => $this->input->post('salary_work_from_home'),
					  'salary_esic_employee'        => $this->input->post('salary_esic_employee'),
					  'salary_pf_employee'          => $this->input->post('salary_pf_employee'),
					  'salary_esic_employer'        => $this->input->post('salary_esic_employer'),
					  'salary_pf_employer'          => $this->input->post('salary_pf_employer'),
					  'salary_professional_tax'     => $this->input->post('salary_professional_tax'),
					  'salary_tds'                  => $this->input->post('salary_tds'),
					  'salary_updated_by'           => $this->session->userdata('_user_id')

	               ];


	                if ($this->user_model->update_salary_details($_user_id, $this->session->userdata('_fin_year_id'), $salary_data)) {

	                	$this->return['success'] = "Salary details updated successfully...";

	                	$this->return['reload'] = TRUE;

	                	$this->return['time'] = 2000;
	                }
	                else{
		            	$this->return['error'] = array();

						$this->return['common_error_msg'] = "Some Problems Occured...Try Again Later";
		            }

					foreach ($_POST as $post_key => $post_value) {
						$this->return['no_error'][$post_key] = NULL;
					}
				}
				else{

					$this->return['error'] = array();

					$this->return['common_error_msg'] = "Please complete fields correctly...";

					foreach ($_POST as $each_post_key => $each_post_val) {
						$this->return['error'][$each_post_key] = form_error($each_post_key);
					}
				}	
			}
		}


		echo json_encode($this->return);
	}
	/********************************Update Salary Details End ***********************************/



	/********************************Leave Applications Start ***********************************/
	public function leave_applications(){

		$_user_id = $this->input->post('user_id') ? $this->input->post('user_id') : $this->session->userdata('_user_id');

		if (!$_user_id) {
			$this->return['error'] = "Invalid data given";
		}
		elseif ($_user_id!=$this->session->userdata('_user_id') && !in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{

			$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);

			if (!$user_data) {
				$this->return['error'] = "Invalid data given";
			}
			else{
				$this->return['success'] = TRUE;

				$this->return['html_id'] = "leave";

				$this->data['_user_id'] = $_user_id;

				$this->return['html'] = $this->load->view('admin/xhr/team-members/leave_applications', $this->data, TRUE);
			}
		}

		echo json_encode($this->return);
	}
	/********************************Leave Applications End ***********************************/



	/********************************Salary Slips Start ***********************************/
	public function salary_slips(){

		$_user_id = $this->input->post('user_id') ? $this->input->post('user_id') : $this->session->userdata('_user_id');

		if (!$_user_id) {
			$this->return['error'] = "Invalid data given";
		}
		elseif ($_user_id!=$this->session->userdata('_user_id') && !in_array($this->session->userdata('user_role_id'), [1,3])) {

			$this->return['error'] = "You are not authorized to access here !";
		}
		else{

			$user_data = $this->user_model->user_list(['_user_id' => $_user_id]);

			if (!$user_data) {
				$this->return['error'] = "Invalid data given";
			}
			else{
				$this->return['success'] = TRUE;


				$this->return['html_id'] = "salary-slips";

				$this->data['_user_id'] = $_user_id;

				$this->return['html'] = $this->load->view('admin/xhr/team-members/salary_slips', $this->data, TRUE);
			}
		}

		echo json_encode($this->return);
	}
	/********************************Salary Slips End ***********************************/


}	