<?php
defined('BASEPATH') OR exit('No direct script access allowed');

/**
* Mail format Library
*/
class Mail_format{

	private $ci;

    private $email_settings;

	public function __construct(){
        // Assign the CodeIgniter super-object
        $this->ci =& get_instance();

        global $DB_ROUTES;
        $this->admin_url = $DB_ROUTES;

        require_once APPPATH."/third_party/phpmailer/class.phpmailer.php";

        $this->ci->load->library('encryption');

        $this->php_mailer = new PHPMailer();

        $settings_keys = [
                           'mailer_enc_type', 'mailer_type', 'mail_bcc', 'mail_content_type',
                           'mail_from_email', 'mail_from_name', 'mail_host', 'mail_password',
                           'mail_port', 'mail_reply_to'
                         ]; 

        $settings_datas = $this->ci->settings_model->get_bulk_settings($settings_keys);

        $all_settings = [];

        if ($settings_datas) {
            foreach ($settings_datas as $i => $row) {
                $all_settings[$row->settings_key] = $row->settings_value;
            }
        }

        $this->email_settings = (object) $all_settings;
        
    }

    public function mail_testing($param){
        $this->php_mailer->isSMTP();
        $this->php_mailer->Debugoutput = 'html';
        $this->php_mailer->SMTPDebug  = 0;
        $this->php_mailer->SMTPAuth   = true;
        $this->php_mailer->SMTPSecure = $param['mailer_enc_type'];
        $this->php_mailer->Mailer     = $param['mailer_type'];
        $this->php_mailer->Host       = $param['mail_host'];
        $this->php_mailer->Port       = $param['mail_port'];

        if ($param['mail_content_type']=='html') {
            $this->php_mailer->IsHTML(true); 
        }
        else{
            $this->php_mailer->IsHTML(FALSE); 
        }
        
        $this->php_mailer->WordWrap   = 80;

        $this->php_mailer->FromName =  $param['mail_from_name'];
    
        $this->php_mailer->Username  = $param['mail_from_email'];
        $this->php_mailer->Password  = $param['mail_password'];

        $this->php_mailer->ClearAllRecipients();

        $this->php_mailer->addAddress($param['mail_testing']);

        $this->php_mailer->AddReplyTo($param['mail_reply_to']);

        $this->php_mailer->Subject = 'Mail Settings Testing'; 
        $this->php_mailer->MsgHTML("Mail Settings Testing Message");

        if ($this->php_mailer->send()) {
            return TRUE;
        }
        else{
            return FALSE;
        }
    }

    public function mail_send($to, $subject, $mailbody, $attachment=NULL, $cc=NULL, $bcc=NULL){

        if (!$this->email_settings) {
            return FALSE;
        }    

    	$this->php_mailer->isSMTP();
		$this->php_mailer->Debugoutput = 'html';
    	$this->php_mailer->SMTPDebug  = 0;
    	$this->php_mailer->SMTPAuth   = true;
    	$this->php_mailer->SMTPSecure = $this->smtp_secure;
        $this->php_mailer->Mailer     = $this->mailer;
        $this->php_mailer->Host       = $this->mail_host;
        $this->php_mailer->Port       = $this->mail_port;

        if ($this->email_type=='html') {
            $this->php_mailer->IsHTML(true); 
        }
        else{
            $this->php_mailer->IsHTML(FALSE); 
        }

        $this->php_mailer->WordWrap   = 80;

        $this->php_mailer->FromName =  $this->from_name;
    
    	$this->php_mailer->Username  = $this->from_email;
        $this->php_mailer->Password  = $this->password;

        $this->php_mailer->ClearAllRecipients();

        $this->php_mailer->AddReplyTo($this->replyto);

         if (is_array($to)) {
        	foreach ($to as $each_to) {
        		$this->php_mailer->addAddress($each_to);
        	}
        }
        else{
        	$this->php_mailer->addAddress($to);
        }

        if (is_array($cc)) {
        	foreach ($cc as $each_cc) {
        		$this->php_mailer->AddCC($each_cc);
        	}        
        }
        elseif ($cc) {
        	$this->php_mailer->AddCC($cc);
        }


        if (is_array($bcc)) {
        	foreach ($bcc as $each_bcc) {
        		$this->php_mailer->AddBCC($each_bcc);
        	}        
        }
        elseif ($bcc) {
        	$this->php_mailer->AddBCC($bcc);
        }


        $this->php_mailer->Subject = $subject; 

        //$mailbody = strip_tags(html_entity_decode($mailbody),'<p><a><ul><ol><li><b><strong><u><i>'); 

        $this->php_mailer->MsgHTML($mailbody);

		if ($this->php_mailer->send()) {

            $this->ci->load->model('mail_model');

            $logs_to  = is_array($to) ? implode(",", $to) : $to;
            $logs_cc  = is_array($cc) ? implode(",", $cc) : $cc;
            $logs_bcc = is_array($bcc) ? implode(",", $bcc) : $bcc;

            $mail_data = [
                            'logs_to'         => $logs_to,
                            'logs_cc'         => $logs_cc,
                            'logs_bcc'        => $logs_bcc,
                            'logs_attachment' => $attachment,
                            'logs_subject'    => $subject,
                            'logs_body'       => htmlspecialchars($mailbody)
                         ];

            $this->ci->mail_model->create_mail_log($mail_data);             

        	return TRUE;
        }
        else{
        	//$this->ci->custom_logs->write_log('mail_error', 'PHP Mailer Error => '.$this->php_mailer->ErrorInfo);
        	return FALSE;
        }
    }


    /***************************************** Add Client Start *******************************/
    public function add_client(array $param){
        $mail_body = $this->ci->load->email_template('add_client_email', $param);

        return $this->mail_send($param['client_email'], 'Client Registration', $mail_body);
    }
    /***************************************** Add Client End *******************************/



    /******************************* Client Register Admin Start *******************************/
    public function client_register_admin(array $param){
        $mail_body = $this->ci->load->email_template('client_register_admin', $param);

        return $this->mail_send($param['client_email'], 'Registration Admin', $mail_body);
    }
    /******************************* Client Register Admin End *******************************/
    



    /******************************* Add User Email Start *******************************/
    public function add_user_email(array $param){
        $mail_body = $this->ci->load->email_template('add_user_email', $param);

        return $this->mail_send($param['user_email'], 'Profile Creation', $mail_body);
    }
    /******************************* Add User Email End *******************************/

    
    /******************************* Add User Email Start *******************************/
    public function forgot_password_mail(array $param){
        $mail_body = $this->ci->load->email_template('forgot_password_mail', $param);

        return $this->mail_send($param['user_email'], 'Forgot Password', $mail_body);
    }
    /******************************* Add User Email End *******************************/


   
    /***************************************** Backend Method Start *******************************/
    private function __encrypt($str){
        $str = $this->ci->encryption->encrypt($str);
        $enc_str = str_replace(array('+', '/', '='), array('-', '_', '~'), $str);

        return $enc_str;
    }

    private function __decrypt($enc_str){
        $enc_str = str_replace(array('-', '_', '~'), array('+', '/', '='), $enc_str);
        $str     = $this->ci->encryption->decrypt($enc_str);

        return $str;
    }
    /***************************************** Backend Method End **********************************/

}