<?php
defined('BASEPATH') OR exit('No direct script access allowed');
/**
*  Clients Model
*/
class Clients_model extends MY_Model{

	public function __construct(){
		parent::__construct();
	}

	public function add_client(array $data){
		return $this->db->insert('clients', $data) ? $this->db->insert_id() : FALSE; 
	}

	public function clients($param=array()){

		if (isset($param['count'])) {
			$select = "COUNT(_client_id) AS count";
		}
		else{
			$select = '_client_id,client_name,client_address,client_city,client_state,client_state_code,client_pincode,
			           client_country,client_phone,client_website,client_email,client_gstin,client_currency,client_is_active,
			           currency_name,currency_code,currency_icon';
		}

		$this->db->select($select);
		$this->db->from('clients c');
		$this->db->join('currencies cc', 'c.client_currency=cc._currency_id', 'LEFT');

		if (isset($param['like'])) {
			$this->db->group_start();
			$this->db->like('client_name', $param['like']);
			$this->db->or_like('client_address', $param['like']);
			$this->db->or_like('client_city', $param['like']);
			$this->db->or_like('client_state', $param['like']);
			$this->db->or_like('client_country', $param['like']);
			$this->db->group_end();
		}

		if (isset($param['count'])) {
			return $this->db->get()->row()->count;
		}
        elseif (isset($param['_client_id']) && $param['_client_id']) {
        	$this->db->where('_client_id', $param['_client_id']);
            return $this->db->get()->row();
        }
        else{

        	$this->db->order_by('_client_id', 'DESC');
			if (isset($param['offset']) && isset($param['limit'])) {
				if ($param['limit']!='-1') {
					$this->db->limit($param['limit'], $param['offset']);
				}	
			}
        	return $this->db->get()->result();
        }

	}

	public function update_client($_client_id, array $data){
		return $this->db->where('_client_id', $_client_id)->update('clients', $data);
	}

	public function client_users($param=array()){
		if (isset($param['count'])) {
			$select = "COUNT(_user_id) AS count";
		}
		else{
			$select = '*';
		}

		$this->db->select($select);
		$this->db->from('users u');
		$this->db->join('client_users cu','cu.cu_user_id=u._user_id','INNER');
		$this->db->join('clients c','c._client_id=cu.cu_client_id','INNER');
		$this->db->join('currencies cc', 'c.client_currency=cc._currency_id', 'LEFT');

		if (isset($param['_client_id']) && $param['_client_id']) {
        	$this->db->where('_client_id', $param['_client_id']);
        }

		if (isset($param['like'])) {
			$this->db->group_start();
			$this->db->like('user_first_name', $param['like']);
			$this->db->or_like('user_last_name', $param['like']);
			$this->db->or_like('user_email', $param['like']);
			$this->db->or_like('user_mobile', $param['like']);
			$this->db->or_like('client_name', $param['like']);
			$this->db->group_end();
		}

		if (isset($param['count'])) {
			return $this->db->get()->row()->count;
		}
        elseif (isset($param['_user_id']) && $param['_user_id']) {
        	$this->db->where('_user_id', $param['_user_id']);
            return $this->db->get()->row();
        }
        else{

        	$this->db->order_by('_user_id', 'DESC');
			if (isset($param['offset']) && isset($param['limit'])) {
				if ($param['limit']!='-1') {
					$this->db->limit($param['limit'], $param['offset']);
				}	
			}
        	return $this->db->get()->result();
        }
	}

	public function add_client_user(array $data){
		return $this->db->insert('client_users', $data) ? $this->db->insert_id() : FALSE;
	}

	public function delete_client_user($_client_id){
		return $this->db->delete('client_users', ['cu_client_id' => $_client_id]);
	}

}