<?php
defined('BASEPATH') OR exit('No direct script access allowed');
/**
*  Projects Model
*/
class Projects_model extends MY_Model{

	public function __construct(){
		parent::__construct();
	}

	public function add_project(array $data){
		return $this->db->insert('projects', $data) ? $this->db->insert_id() : FALSE; 
	}

	public function projects($param = array()){
		if (isset($param['count'])) {
			$select = "COUNT(_project_id) AS count";
		}
		else{
			$select = '_project_id, project_title, project_description, project_start_date, project_deadline, project_price, project_skills, project_created, project_status, _client_id, client_name, currency_name, currency_code, currency_icon';
		}

		$this->db->select($select);
		$this->db->from('projects p');
		$this->db->join('clients c','p.project_client_id=c._client_id','INNER');
		$this->db->join('currencies cc', 'c.client_currency=cc._currency_id', 'LEFT');

		if (isset($param['like'])) {
			$this->db->group_start();
			$this->db->like('project_title', $param['like']);
			$this->db->or_like('client_name', $param['like']);
			$this->db->or_like('project_start_date', $param['like']);
			$this->db->or_like('project_price', $param['like']);
			$this->db->or_like('project_deadline', $param['like']);
			$this->db->group_end();
		}

		if (isset($param['count'])) {
			return $this->db->get()->row()->count;
		}
        elseif (isset($param['_project_id']) && $param['_project_id']) {
        	$this->db->where('_project_id', $param['_project_id']);
            return $this->db->get()->row();
        }
        else{

        	$this->db->order_by('_project_id', 'DESC');
			if (isset($param['offset']) && isset($param['limit'])) {
				if ($param['limit']!='-1') {
					$this->db->limit($param['limit'], $param['offset']);
				}	
			}
        	return $this->db->get()->result();
        }
	}

	public function project_members($param = array()){
		if (isset($param['count'])) {
			$select = "COUNT(_member_id) AS count";
		}
		else{
			$select = '_member_id, _user_id, user_first_name, user_last_name, user_job_title, _urole_id, urole_title, _project_id, project_title';
		}

		$this->db->select($select);
		$this->db->from('project_members pm');
		$this->db->join('projects p', 'pm.member_project_id=p._project_id','INNER');
		$this->db->join('users u', 'pm.member_user_id=u._user_id', 'INNER');
		$this->db->join('user_roles ur', 'u.user_role_id=ur._urole_id', 'INNER');

		if(isset($param['_project_id']) && $param['_project_id']){
			$this->db->where('_project_id',$param['_project_id']);
		}

		if (isset($param['like'])) {
			$this->db->group_start();
			$this->db->like('user_first_name', $param['like']);
			$this->db->or_like('user_last_name', $param['like']);
			$this->db->or_like('user_job_title', $param['like']);
			$this->db->group_end();
		}

		if (isset($param['count'])) {
			return $this->db->get()->row()->count;
		}
        elseif (isset($param['_member_id']) && $param['_member_id']) {
        	$this->db->where('_member_id', $param['_member_id']);
            return $this->db->get()->row();
        }
        else{

        	$this->db->order_by('_member_id', 'DESC');
			if (isset($param['offset']) && isset($param['limit'])) {
				if ($param['limit']!='-1') {
					$this->db->limit($param['limit'], $param['offset']);
				}	
			}
			if(isset($param['res_array']) && $param['res_array']){
				return $this->db->get()->result_array();
			}
        	return $this->db->get()->result();
        }
	}

	public function add_project_member_batch(array $data){
		return $this->db->insert_batch('project_members', $data) ? TRUE : FALSE;
	}

	/*public function delete_project_members($_project_id){
		return $this->db->delete('project_members',['member_project_id' => $_project_id]) ? TRUE : FALSE;
	}*/

	public function delete_project_member($_member_id){
		return $this->db->delete('project_members',['_member_id' => $_member_id]) ? TRUE : FALSE;
	}

	public function update_project($_project_id, array $data){
		return $this->db->where('_project_id', $_project_id)->update('projects', $data);
	}

	public function add_milestone(array $data){
		return $this->db->insert('milestones', $data) ? $this->db->insert_id() : FALSE;
	}

	public function milestones($param = array()){
		if (isset($param['count'])) {
			$select = "COUNT(_milestone_id) AS count";
		}
		else{
			$select = '_milestone_id, milestone_title, milestone_description, milestone_due_date, milestone_created, milstone_status, _project_id, project_title';
		}

		$this->db->select($select);
		$this->db->from('milestones m');
		$this->db->join('projects p','m.milestone_project_id=p._project_id','INNER');

		if (isset($param['_project_id']) && $param['_project_id']) {
        	$this->db->where('_project_id', $param['_project_id']);
        }

		if (isset($param['like'])) {
			$this->db->group_start();
			$this->db->like('milestone_title', $param['like']);
			$this->db->or_like('project_title', $param['like']);
			$this->db->group_end();
		}

		if (isset($param['count'])) {
			return $this->db->get()->row()->count;
		}
        elseif (isset($param['_milestone_id']) && $param['_milestone_id']) {
        	$this->db->where('_milestone_id', $param['_milestone_id']);
            return $this->db->get()->row();
        }
        else{

        	$this->db->order_by('_milestone_id', 'DESC');
			if (isset($param['offset']) && isset($param['limit'])) {
				if ($param['limit']!='-1') {
					$this->db->limit($param['limit'], $param['offset']);
				}	
			}
        	return $this->db->get()->result();
        }
	}

	public function update_milestone($_milestone_id, array $data){
		return $this->db->where('_milestone_id', $_milestone_id)->update('milestones', $data);
	} 

}